clear all
set matsize 11000
set maxvar 32767
set more off


ssc install estout,replace
ssc install ivreg2,replace
ssc install reghdfe,replace
ssc install tuples,replace
ssc install ivreghdfe,replace
ssc install winsor,replace
ssc install ftools,replace
ssc install xtivreg2,replace
ssc install avar,replace
ssc install asreg,replace
ssc install pls, replace
ssc install shapley2, replace
ssc install newey2, replace 
ssc install outreg2, replace 
ssc install ranktest, replace

* Install moremata (sometimes used by ftools but not needed for reghdfe)
cap ssc install moremata

reghdfe, compile

* Put Working Directory Here
cd xxx



*************************************************************************************************************************************************************
*************************************************************************************************************************************************************
****************************************    Bills Data Creation              ********************************************************************************
*************************************************************************************************************************************************************
*************************************************************************************************************************************************************

*** Creating OIS Imputation 

import delimited "Data/Input_files/Proprietary/ois_updated.csv", clear 
forvalues i=1(1)3 {
	local j=`i'*7
	rename  ois`i'w  ois_`j'
}
forvalues i=1(1)11 {
	local j=`i'*30
	rename  ois`i'm  ois_`j'
}

forvalues i=15(3)21 {
	local j=`i'*30
	rename  ois`i'm  ois_`j'
}

forvalues i=1(1)7 {
	local j=`i'*365
	rename  ois`i'y  ois_`j'
}
rename  ois10y  ois_3650
foreach var of varlist ois_300-ois_1095 ois_1460 - ois_1825 ois_2190-ois_270 {
	replace `var'="." if `var'=="ND"
	destring `var', replace	
}

split date, p("/")
destring date*, replace
drop date 
gen date=mdy(date1, date2, date3)
format date %d 


gen ois_0=.
reshape long ois_, i(date) j(time_to_mat_early)
drop if time_to_mat_early>365
gen payable_early=date+time_to_mat
gen time_to_m_orig=time_to_mat_early
*Getting the right time to Maturity for each month and year
gen leap_year=0
replace leap_year=1 if year(date)==2004 | year(date)==2008 | year(date)==2012 | year(date)==2016
gen leap_year_m1=0
replace leap_year_m1=1 if year(date)==2003 | year(date)==2007 | year(date)==2011 | year(date)==2015

forvalues i=30(30)330 {
	local j=`i'/30
	replace payable_early=mdy(month(date)+`j', day(date), year(date)) if time_to_mat==`i' & month(date)+`j'<13
	replace payable_early=mdy(month(date)+`j', 30, year(date)) if time_to_mat==`i' & month(date)+`j'<13 & (month(date)+`j'==4 | month(date)+`j'==6 | month(date)+`j'==9 | month(date)+`j'==11 ) & day(date)==31
	replace payable_early=mdy(month(date)+`j', 28, year(date)) if time_to_mat==`i' & month(date)+`j'<13 & month(date)+`j'==2 & day(date)>28 & leap_year==0
	replace payable_early=mdy(month(date)+`j', 29, year(date)) if time_to_mat==`i' & month(date)+`j'<13 & month(date)+`j'==2 & day(date)>29 & leap_year==1
	replace payable_early=mdy(month(date)+`j'-12, day(date), year(date)+1) if time_to_mat==`i' & month(date)+`j'>=13
	replace payable_early=mdy(month(date)+`j'-12, 30, year(date)+1) if time_to_mat==`i' & month(date)+`j'>=13 & (month(date)+`j'-12==4 | month(date)+`j'-12==6 | month(date)+`j'-12==9 | month(date)+`j'-12==11 ) & day(date)==31	
	replace payable_early=mdy(month(date)+`j'-12, 28, year(date)+1) if time_to_mat==`i' & month(date)+`j'>=13 & month(date)+`j'-12==2 & day(date)>28 & leap_year_m1==0
	replace payable_early=mdy(month(date)+`j'-12, 29, year(date)+1) if time_to_mat==`i' & month(date)+`j'>=13 & month(date)+`j'-12==2 & day(date)>29 & leap_year_m1==1
	replace time_to_mat=payable_early-date if time_to_mat==`i'
}

forvalues j=1(1)10 {
	local i=`j'*365
	replace payable_early=mdy(month(date), day(date), year(date)+`j') if time_to_mat==`i'
	replace payable_early=mdy(month(date), 28, year(date)+`j') if time_to_mat==`i' & month(date)==2 & day(date)==29 & leap_year==1
	replace time_to_mat=payable_early-date if time_to_mat==`i'
	
}


drop if time_to_mat>366


**** Creating the imputed OIS values
tsset date time_to_mat_early
tsfill
replace payable_early=date+time_to_mat

gen ttm_sq=time_to_mat*time_to_mat
regress ois_ i.date##c.time_to_mat i.date##c.ttm_sq if time_to_mat<=365 
predict ois_predicted if time_to_mat<=365



gen ois_imputed=ois_predicte*100
drop  time_to_mat*

compress
sort date

save "Data/Created_files/OIS_imputation_all_years.dta", replace





************************************************************************************************
********** Federal Funds Rate Futures Compilation **********************************************



import delimited "Data/Input_files/Public/fomc_dates.csv", varnames(1) encoding(ISO-8859-2) clear 
split date, p("/")
destring, replace
drop date
gen date=mdy(date1, date2, date3)
rename fomcdummy fomc_dates
drop if fomc_dates=="NA"
destring, replace
save "Data/Created_files/fomc_dates.dta", replace


import delimited "Data/Input_files/Proprietary/ff.csv", varnames(1) encoding(ISO-8859-2) clear 
foreach var of varlist ff11 ff12 {
	replace `var'="." if `var'=="ND"
	replace `var'="." if `var'=="NC"
}
split date, p("/")
destring, replace
drop date
gen date=mdy(date1, date2, date3)
format date %d
save "Data/Created_files/ff1.dta", replace




import delimited "Data/Input_files/Proprietary/securities.csv", varnames(1) encoding(ISO-8859-2) clear 
gen year=int(dt/10000)
gen month=int((dt-10000*year)/100)
gen day=dt-year*10000-month*100
gen date=mdy(month, day, year)
format date %d
forvalues i=1(1)10 {
	replace ff`i'="." if ff`i'=="NA"
}
keep date ff*
destring, replace
joinby date using "Data/Created_files/ff1.dta", unmatched(both)
drop _merge
save "Data/Created_files/ff.dta", replace
*********************************************



import delimited "Data/Input_files/Public/effr.csv", varnames(1) encoding(ISO-8859-2) clear 
split date, p("/")
destring, replace
drop date
gen date=mdy(date1, date2, date3)
save "Data/Created_files/effr.dta", replace

tsset date
gen month_to_date=effr if day(date)==1
forvalues i=2(1)31 {
	replace month_to_date=month_to_date[_n-1]+ effr if day(date)==`i'
}
gen avg_effr=month_to_date/day(date)

joinby date using "Data/Created_files/fomc_dates.dta", unmatched(master)
drop _merge
joinby date using "Data/Created_files/ff.dta", unmatched(master)
replace fomc_dates=0 if missing(fomc_dates)
sort date

forvalues i=1(1)12 {
	gen has_ff`i'=0
	replace has_ff`i'=date if !missing(ff`i')
	egen min_date_`i'=min(has_ff`i')
	egen max_date_`i'=max(has_ff`i')
	sort date
	replace ff`i'=ff`i'[_n-1] if missing(ff`i') & !missing(ff`i'[_n-1]) & date>=min_date_`i' & date<=max_date_`i'
}

gen fomc_date=fomc_date*date
bysort date3 date1: egen has_fomc=total(fomc_dates)
bysort date3 date1: egen fomc_month_day=max(fomc_date)
bysort date3 date1: egen tot_days=max(date2)

gen effr_0=effr
gen tot_effr_0=month_to_date-effr_0
gen tot_effr_todate=0
gen tot_effr_foravg_0=0
forvalues k=1(1)12 {
	gen tot_effr_`k'_0=0
}
forvalues i=1(1)365 {
*forvalues i=1(1)61 {
	local m=`i'-1
	gen date_`i'=date+`i'
	local j=`i'-1
	gen tot_effr_`i'=0
	replace tot_effr_`i'=tot_effr_`j'+effr_`j' if day(date_`i')!=1
	gen effr_`i'=.
	replace effr_`i'=effr_`j' if  month(date)==month(date_`i') & has_fomc==1 & date_`i'<fomc_month_day & year(date)==year(date_`i')
	replace effr_`i'=(ff1*tot_days-tot_effr_`i')/(tot_days - day(date_`i') +1) if date_`i'==fomc_month_day & has_fomc==1 & month(date)==month(date_`i') & year(date)==year(date_`i')
	replace effr_`i'=effr_`j' if date_`i'>fomc_month_day & has_fomc==1 & month(date)==month(date_`i') & year(date)==year(date_`i') & fomc_month_day>date
	replace effr_`i'=(ff1*tot_days-tot_effr_0)/(tot_days-date2 +1) if has_fomc==0 & month(date)==month(date_`i') & year(date)==year(date_`i')
	replace effr_`i'=(ff1*tot_days-tot_effr_0)/(tot_days-date2 +1) if has_fomc==1 & month(date)==month(date_`i') & year(date)==year(date_`i') & fomc_month_day<=date
	forvalues k=1(1)11 {
		local l=`k'+1
		gen tot_effr_`k'_`i'=0
		replace tot_effr_`k'_`i' = tot_effr_`k'_`j' + effr_`j' if  month(date)==month(date_`i')-`k'  & year(date)==year(date_`i') & day(date_`i')!=1
		replace tot_effr_`k'_`i'=tot_effr_`k'_`j' + effr_`j' if  month(date)==month(date_`i')-`k' + 12  & year(date)==year(date_`i')  -1 & day(date_`i')!=1
		replace effr_`i'=effr_`j' if  month(date)==month(date_`i')-`k' & has_fomc[_n+`i']==1 & date_`i'<fomc_month_day[_n+`i'] & year(date)==year(date_`i')
		replace effr_`i'=effr_`j' if  month(date)==month(date_`i')-`k'+12 & has_fomc[_n+`i']==1 & date_`i'<fomc_month_day[_n+`i'] & year(date)==year(date_`i')-1
		replace effr_`i'=(ff`l'*tot_days[_n+`i']-tot_effr_`k'_`i')/(tot_days[_n+`i'] - day(date_`i') +1) if date_`i'==fomc_month_day[_n+`i'] & has_fomc[_n+`i']==1 & month(date)==month(date_`i')-`k' & year(date)==year(date_`i')
		replace effr_`i'=(ff`l'*tot_days[_n+`i']-tot_effr_`k'_`i')/(tot_days[_n+`i'] - day(date_`i') +1) if date_`i'==fomc_month_day[_n+`i'] & has_fomc[_n+`i']==1 & month(date)==month(date_`i') -`k' + 12 & year(date)==year(date_`i')-1
		replace effr_`i'=effr_`j' if date_`i'>fomc_month_day[_n+`i'] & has_fomc[_n+`i']==1 & month(date)==month(date_`i')-`k' & year(date)==year(date_`i')
		replace effr_`i'=effr_`j' if date_`i'>fomc_month_day[_n+`i'] & has_fomc[_n+`i']==1 & month(date)==month(date_`i')-`k'+12 & year(date)==year(date_`i')-1
		replace effr_`i'=ff`l' if has_fomc[_n+`i']==0 & month(date)==month(date_`i')-`k' & year(date)==year(date_`i')
		replace effr_`i'=ff`l' if has_fomc[_n+`i']==0 & month(date)==month(date_`i')-`k'+12 & year(date)==year(date_`i')-1
	}

	gen tot_effr_foravg_`i'=tot_effr_foravg_`j'+effr_`i' 
	gen avg_effr_`i'=(tot_effr_foravg_`i')/`i'
	}
keep date* effr* avg_effr* ff*

reshape long date_ effr_ avg_effr_, i(date) j( day)
rename date_ payable_early
rename effr_ expected_effr
rename avg_effr avg_effr1
rename avg_effr_ avg_effr

save "Data/Created_files/avg_effr.dta", replace

************************************************************************************************

*** Pulling public auction data so know the type of security 
forvalues i=1(1)8 {
import delimited "Data/Input_files/Public/auctions_`i'.csv", clear
foreach var of varlist auctiondate issuedate maturitydate {
	split `var', p("/")
	destring `var'*, replace
	rename `var' `var'_st
	gen `var'=mdy(`var'1, `var'2, `var'3)
	drop `var'_st `var'1 `var'2 `var'3
	format `var' %d
}
save "Data/Created_files/auctions_`i'.dta", replace
}

use "Data/Created_files/auctions_1.dta", clear
forvalues i=2(1)8 {
	append using "Data/Created_files/auctions_`i'.dta", force
} 

keep cusip securitytype cashmanagementbillcmb floatingrate tips
duplicates drop
bysort cusip: egen count=count(_n)
replace cashmanagementbillcmb="No" if count==2
duplicates drop
drop count
gen tcusip=substr(cusip,1,8)
save "Data/Created_files/bill_type.dta", replace

*******
* Bringing in the CRSP Data and keeping only regular bills (not CMBs)

import delimited "Data/Input_files/Proprietary/crsp_treasury_1990_2019_for_submission.csv", clear 

split caldt, p("/")
split tmatdt, p("/")
split tdatdt, p("/")


destring, replace
gen date=mdy(caldt1, caldt2, caldt3)
gen payable_early=mdy(tmatdt1, tmatdt2, tmatdt3)
gen tdated=mdy(tdatdt1, tdatdt2, tdatdt3)

drop if date<tdated & !missing(tdated)
* Dropping the days for a security that was initially issued as a CMB before normal bill 
drop if payable_early==mdy(4,24,2014) & date<mdy(10,24,2013)
joinby tcusip using "Data/Created_files/bill_type.dta", unmatched(master)
drop _merge

* restricting data to just bills
keep if itype==4
drop if cashmanagementbillcmb=="Yes"

***************** Creating Bid-Ask Spreads *************************************






* generating time to maturity var
gen time_to_mat_early=payable_early-date




* generating annual yield 
* yield in CRSP data is daily promised value 
* deliberately multiplying by 100 twice to get in basis points
gen yld_early=((1+tdyld)^365-1)*100*100

** Creating bid-ask spreads
gen bid_yld_daily=((100/tdbid)^(1/time_to_mat_early))-1
gen ask_yld_daily=((100/tdask)^(1/time_to_mat_early))-1
gen avg_yld_daily=((bid_yld_daily+ask_yld_daily)/2)

gen bid_ask_spread_yield=((1+bid_yld_daily)^365-(1+ask_yld_daily)^365)*10000


drop if time_to_mat_early<5
replace bid_ask_spread_yield=. if payable_early==17002 & date==16975
replace bid_ask_spread_yield=. if payable_early==12963 & date==12775




keep date payable_early yld_early bid_ask_spread_yield time_to_mat_early 







gen ba_type=0
replace ba_type=1 if  date<mdy(4,1,1991)
replace ba_type=2 if date>=mdy(4,1,1991) & date<mdy(10,16,1996)
replace ba_type=3 if date>=mdy(10,16,1996) & date<mdy(10,21,1998)
replace ba_type=4 if date>=mdy(10,21,1998) & date<mdy(2,1,2009)
replace ba_type=5 if date>=mdy(2,1,2009) & date<mdy(3,7,2012)
replace ba_type=6 if date>=mdy(3,7,2012) & date<mdy(10,26,2015)
replace ba_type=7 if date>=mdy(10,26,2015)



gen normalized_bid_ask_spread=.
forvalues i=1/7 {
	disp `i'
	qui su bid_ask_spread_yield if ba_type==`i'
	disp `r(mean)' 
	disp `r(sd)'
	replace normalized_bid_ask_spread= (bid_ask_spread_yield - `r(mean)')/`r(sd)' if ba_type==`i'
}








* Key Dates

* 2011 Episode
local key_2011 = mdy(8,2,2011)
* 2013 Episode
local key_2013 = mdy(10,17,2013)

local max_2011 = `key_2011' + 21
local max_2013 = `key_2013' + 21

local min_2011 = `key_2011' - 21
local min_2013 = `key_2013' - 21

*
* 2011 Episode
local start_2011 = mdy(5,17,2011)
local maxatrisk_2011 = mdy(9,2,2011)
* 2013 Episode
local start_2013 = mdy(5,19,2013)
local maxatrisk_2013 = mdy(11,17,2013)


* Create At-risk securities and date dummies during episodes
foreach ep in  2011 2013 {
	gen at_risk_`ep'=0
	replace at_risk_`ep'=1 if payable_early>`start_`ep'' & payable_early<`maxatrisk_`ep''
	local first=`min_`ep''
	local last=`max_`ep''
forvalues i=`first'/`last' {
	local month=month(`i')
	local day=day(`i')
	local year=year(`i')
	gen d_`year'_`month'_`day'=0 
	replace d_`year'_`month'_`day'=1 if date==`i'
	su d_`year'_`month'_`day', meanonly
	replace d_`year'_`month'_`day'=. if `r(min)'==`r(max)'
	missings dropvars d_`year'_`month'_`day', force
}
}

egen at_risk=rowmax(at_risk_*)

* Create date - payable dummies for at-risk securities
foreach ep in 2011 2013  {
	local first=`min_`ep''
	local last=`max_`ep''
	local p_start = `key_`ep'' - 15
	local p_end = `key_`ep'' + 45
	forvalues i=`first'/`last' {
		local date_month=month(`i')
		local date_day=day(`i')
		local date_year=year(`i')
		forvalues j=`p_start'/`p_end' {
			local pay_month=month(`j')
			local pay_day=day(`j')
			local pay_year=year(`j')
			gen p_`pay_year'_`pay_month'_`pay_day'_d_`date_year'_`date_month'_`date_day'=0
			replace p_`pay_year'_`pay_month'_`pay_day'_d_`date_year'_`date_month'_`date_day'=1 if date==`i' & payable_early==`j' & at_risk_`ep'==1
			su p_`pay_year'_`pay_month'_`pay_day'_d_`date_year'_`date_month'_`date_day', meanonly
			replace p_`pay_year'_`pay_month'_`pay_day'_d_`date_year'_`date_month'_`date_day'=. if `r(min)'==`r(max)'
			missings dropvars p_`pay_year'_`pay_month'_`pay_day'_d_`date_year'_`date_month'_`date_day', force

		}
	}
}



* Merge OIS and Average expected federal funds rate data
joinby date payable_early using "Data/Created_files/OIS_imputation_all_years.dta", unmatched(master)
drop _merge 
drop ois_ time_to_m_orig leap_year leap_year_m1 ttm_sq
* Need to change
joinby date payable_early using "Data/Created_files/avg_effr.dta", unmatched(master)












** First differenced variables for regressions



foreach var of varlist yld_early ois_imputed bid_ask_spread_yield normalized_bid_ask_spread  avg_effr expected_effr d_* p_*    {

  bysort payable_early (date): gen fd_`var' = `var' - `var'[_n - 1]
  
}


foreach ep in 2011 2013  {
	egen window_`ep'=rowmax(d_`ep'_*)
}
gen window_2012=0

replace window_2013=0 if year(date)==2013 & month(date)<6

egen window=rowmax(d_*)

gen fd_win_bid_ask_sp_yield=0
replace fd_win_bid_ask_sp_yield=fd_bid_ask_spread_yield if window==1
gen fd_win_norm_bid_ask_spread=0
replace fd_win_norm_bid_ask_spread=fd_normalized_bid_ask_spread if window==1


* saving Daily bills data
* Need to change
save "Data/Created_files/bill_basic_regressions_CRSP_1990_2020.dta", replace




**************************************************************************************************************************
**************************************************************************************************************************
**************************************************************************************************************************
************** Creating the daily control variables **********************************************************************



* refcorp data 
import delimited "Data/Input_files/Proprietary/refcorp_combined.csv", encoding(ISO-8859-2) clear 
split date, p("/")
destring, replace
drop date 
gen date=mdy(date1, date2, date3)
format date %d 
save "Data/Created_files/refcorp_combined.dta", replace

**************************************************************************************************************************
** On the Run Sveny spread 
* SVENY Data
import delimited "Data/Input_files/Public/sveny_curve.csv", encoding(ISO-8859-2) clear 
split date, p("/")
destring, replace
drop date 
gen date=mdy(date1, date2, date3)
format date %d 
save "Data/Created_files/sveny_curve.dta", replace




import delimited "Data/Input_files/Proprietary/crsp_treasury_1990_2019_for_submission.csv", clear 

split caldt, p("/")
split tmatdt, p("/")
split tdatdt, p("/")


destring, replace
gen date=mdy(caldt1, caldt2, caldt3)
gen payable_early=mdy(tmatdt1, tmatdt2, tmatdt3)
gen tdated=mdy(tdatdt1, tdatdt2, tdatdt3)

drop if date<tdated & !missing(tdated)
joinby tcusip using "Data/Created_files/bill_type.dta", unmatched(master)
drop _merge

* keeping ony coupons
keep if itype<3
drop if cusip==""

* Keeping only the original 10-year maturity securities
gen original_tenor = payable_early - tdated 
drop if original_tenor<3600
drop if original_tenor>3700
* Only keeping on the run securities
bysort date: egen most_recent_dated = max(tdated)
keep if tdated == most_recent_dated

gen yld_early=((1+tdyld)^360-1)*100*100
drop if missing(yld_early)



joinby date using  "Data/Created_files/sveny_curve.dta", unmatched(master)
gen tenyear_spread=yld_early-100*svenpy10
rename yld_early tenyear_yield


forvalues i=0(1)9 {
	local j=2*`i'+1
	local k=2*`i'+2
	gen coupon_`j'=mdy(month(payable_early)+6, day(payable_early), year(payable_early)+`i'-10) if month(payable_early)<7
	replace coupon_`j'=mdy(month(payable_early)-6, day(payable_early), year(payable_early)+`i'-9) if month(payable_early)>=7
	format coupon_`j' %d
	gen coupon_`k'=mdy(month(payable_early), day(payable_early), year(payable_early)+`i'-9) 
	format coupon_`k' %d
}


forvalues i=1(1)20 {
	local n=(coupon_`i'-date)/360
	gen n_`i'=(coupon_`i'-date)/360
	gen ft_`i'=beta0 + beta1 * exp(-n_`i'/tau1) + beta2 * (n_`i'/tau1) * exp(-n_`i'/tau1) + beta3 * (n_`i'/tau2) * exp(-n_`i'/tau2)
	gen yt_`i'=beta0 + beta1 * ((1-exp(-n_`i'/tau1))/(n_`i'/tau1)) + beta2 * ((1-exp(-n_`i'/tau1))/(n_`i'/tau1)-exp(-n_`i'/tau1)) + beta3 * ((1-exp(-n_`i'/tau2))/(n_`i'/tau2)-exp(-n_`i'/tau2))
	gen disc_coup_`i'=(tcouprt/2)/((1+(yt_`i'/100))^n_`i') if coupon_`i'-date>0
	replace disc_coup_`i'=0 if coupon_`i'-date<=0
}
gen price=100/((1+(yt_20/100))^n_20)
forvalues i=1(1)20 {
	replace price=price+disc_coup_`i'
}






gen accrued_interest=(tcouprt/2)*((coupon_1 - date)/(coupon_1 - tdated)) 


gen yield = tenyear_yield/100
gen ytm=yt_20/100
gen diff=price - tcouprt*(1-(1/((1+ytm)^n_20)))/ytm-100/((1+ytm)^n_20)
gen ytm_temp=ytm
gen diff_min0=diff
gen price_temp=price
forvalues i=1(1)100 {
	local j=`i'-1
	gen ytm_min`i'=ytm-`i'/10000
	gen price_`i'=100/((1+(ytm_min`i'))^n_20)
	forvalues k=1(1)20 {
		gen disc_coup_a`i'_`k'=(tcouprt/2)/((1+(ytm_min`i'))^n_`k') 
		replace price_`i'=price_`i'+disc_coup_a`i'_`k'
	}
	gen diff_min`i'=price - price_`i'
	replace ytm_temp=ytm_min`i' if diff_min`i'<0 & diff_min`j'>0
	replace price_temp=price_`i' if diff_min`i'<0 & diff_min`j'>0
}
drop diff
gen diff=price - price_temp
drop ytm_min* diff_*
gen ytm_tempa=ytm_temp
gen diff_min0=diff
forvalues i=1(1)1000 {
	local j=`i'-1
	gen ytm_min`i'=ytm_temp+`i'/10000000
	gen price_b`i'=100/((1+(ytm_min`i'))^n_20)
	forvalues k=1(1)20 {
		gen disc_coup_b`i'_`k'=(tcouprt/2)/((1+(ytm_min`i'))^n_`k') 
		replace price_b`i'=price_b`i'+disc_coup_b`i'_`k'
	}
	gen diff_min`i'=price - price_b`i'
	replace ytm_tempa=ytm_min`i' if diff_min`i'>0 & diff_min`j'<0
	replace price_temp=price_b`i' if diff_min`i'<0 & diff_min`j'>0
}

replace ytm=ytm_tempa 
drop diff* ytm_*
gen diff=price - price_temp
gen onrun_svenyspread=10000*ytm-tenyear_yield
gen onrun_ytm_svenyspread=10000*ytm-yield


keep date tenyear_spread tenyear_yield onrun_svenyspread ytm date yield
save "Data/Created_files/tenyearspread.dta", replace




**************************************************************************************************************************

* TED Rate spread Data
import delimited "Data/Input_files/Public/TEDRATE.csv", encoding(ISO-8859-2) clear 
split date, p("/")
destring, replace
drop date 
gen date=mdy(date1, date2, date3)
format date %d 
save "Data/Created_files/tedrate.dta", replace

* Other data
import delimited "Data/Input_files/Proprietary/securities.csv", encoding(ISO-8859-2) clear 
foreach var of varlist ff1-ontherunspread30b {
	replace `var'="." if `var'=="NA"
}
gen year=int(dt/10000)
gen month=int((dt-10000*year)/100)
gen day=dt-year*10000-month*100
gen date=mdy(month, day, year)
format date %d
destring, replace
save "Data/Created_files/ff_fnma_ontherunspread.dta", replace

* Constant Maturity Securities
import delimited "Data/Input_files/Public/constant_maturity.csv", clear 
split date, p("/") destring
drop date 
gen date=mdy(date1, date2, date3)
save "Data/Created_files/constant_maturity.dta", replace

***************************************************************************************
**** Treasury Futures Two Year Basis ***********************************************************

import delimited "Data/Input_files/Proprietary/two_year_futures.csv", clear 
split trade_date, p("-")
destring, replace
gen date=mdy(trade_date2, trade_date3, trade_date1)
drop if settlement==0
gen obs=_n
gen contract_date=mdy(contract_month, 1, contract_year)
drop if month(contract_date)<month(date) & year(contract_date)==year(date)
drop if year(contract_date)<year(date)
drop if month(contract_date)==month(date) & year(contract_date)==year(date)
bysort date (contract_date): gen num=_n

* Pricing
gen futures_price_a = int(settlement/1000) if settlement>50000
gen futures_price_b = (settlement - 1000*futures_price_a)  if settlement>50000
gen futures_price_c = int(futures_price_b/10) if settlement>50000
gen futures_price_d = (settlement - 1000*futures_price_a - 10 * futures_price_c)  if settlement>50000
gen futures_price = futures_price_a + futures_price_c/32 if futures_price_d==0
replace futures_price = futures_price_a + futures_price_c/32 + 1/128 if futures_price_d==2
replace futures_price = futures_price_a + futures_price_c/32 + 1/64 if futures_price_d==5
replace futures_price = futures_price_a + futures_price_c/32 + 3/128 if futures_price_d==7
replace futures_price = settlement if settlement<150
replace futures_price=futures_price_a + futures_price_c/32 if missing(futures_price) & futures_price_b<32
drop if missing(futures_price)
save "Data/Created_files/two_year_futures.dta", replace

* Creating the two-year match
import delimited "Data/Input_files/Proprietary/crsp_treasury_1990_2019_for_submission.csv", clear 

split caldt, p("/")
split tmatdt, p("/")
split tdatdt, p("/")


destring, replace
gen date=mdy(caldt1, caldt2, caldt3)
gen payable_early=mdy(tmatdt1, tmatdt2, tmatdt3)
gen tdated=mdy(tdatdt1, tdatdt2, tdatdt3)

drop if date<tdated & !missing(tdated)
joinby tcusip using "Data/Created_files/bill_type.dta", unmatched(master)
drop _merge


* keeping ony coupons
keep if itype<3

* Only keeping securities initially issued with less than 5 years and 3 months to maturity
drop if year(payable_early)>year(tdated)+6
drop if year(payable_early)==year(tdated)+6 & month(tdated)<10
drop if year(payable_early)==year(tdated)+6 & month(payable_early)>month(tdated)+9
drop if  year(payable_early)==year(tdated)+5 & month(payable_early)>month(tdated)+3 & month(tdated)<10

* Only keeping securities with at least one year and nine months to maturity
gen year_to_mat=year(payable_early)-year(date) if month(payable_early)>month(date)
replace year_to_mat=year(payable_early)-year(date) if month(payable_early)==month(date) & day(payable_early)>=day(date)
replace year_to_mat=year(payable_early)-year(date)-1 if month(payable_early)<month(date)
replace year_to_mat=year(payable_early)-year(date)-1 if month(payable_early)==month(date) & day(payable_early)<day(date)

gen month_to_mat = month(payable_early)-month(date) if day(payable_early)>=day(date)  & month(payable_early)>=month(date)
replace month_to_mat = month(payable_early)-month(date)-1 if day(payable_early)<day(date)  & month(payable_early)>month(date)
replace month_to_mat = month(payable_early)-month(date)+11 if day(payable_early)<day(date)  & month(payable_early)==month(date)

replace month_to_mat = month(payable_early)-month(date) + 12 if day(payable_early)>=day(date)  & month(payable_early)<month(date)
replace month_to_mat = month(payable_early)-month(date)+ 11 if day(payable_early)<day(date)  & month(payable_early)<month(date)
drop if year_to_mat==0
drop if year_to_mat==1 & month_to_mat<9

joinby date using "Data/Created_files/two_year_futures.dta", unmatched(master)

drop if missing(contract_month)
gen initial_date=mdy(contract_month+9,1,(contract_year)+1)
replace initial_date=mdy(contract_month-3,1,(contract_year)+2) if contract_month>3
gen last_date=mdy(contract_month+3,30,(contract_year)+2)
replace last_date=mdy(contract_month-3,30,(contract_year)+3) if contract_month>9
replace last_date=mdy(contract_month+3,31,(contract_year)+2) if contract_month==2 | contract_month==4 | contract_month==5 | contract_month==7 | contract_month==9 
replace last_date=mdy(contract_month-9,31,(contract_year)+3) if contract_month==10 | contract_month==12

format initial_date %d 
format last_date %d 


gen year_del=year(payable_early)-contract_year if month(payable_early)>=contract_month
replace year_del=year(payable_early)-contract_year-1 if month(payable_early)<contract_month

gen month_del = month(payable_early)-contract_month if month(payable_early)>=contract_month
replace month_del = month(payable_early)-contract_month+12 if month(payable_early)<contract_month





drop if payable_early<initial_date
drop if payable_early>last_date

* Creating Conversion Factor
gen coupon = tcouprt/100
gen n = year_del
gen z = month_del
gen v = z if z< 7 
replace v = z - 6 if z>=7
gen a = (1/1.03)^(v/6)
gen b = (coupon/2)*((6-v)/6)
gen c = (1/1.03)^(2*n) if z<7
replace c=(1/1.03)^(2*n+1) if z>=7
gen d = (coupon/0.06)* (1-c)
gen conversion_factor = a * ((coupon/2)+c+d)-b


gen basis=((tdbid + tdask)/2) - futures_price * conversion_factor 
bysort date num: egen min_basis=min(basis)
keep if basis==min_basis
keep date contract_date basis
drop if missing(basis)
bysort date (contract_date): gen num=_n
bysort num contract_date (date): gen num1=_n
gen new_contract=0
replace new_contract=1 if num1==1
keep if num==1
rename basis basis_2y1

save "Data/Created_files/futures_basis.dta", replace



****************************************************************************************
****** Cleaning the CDS Data ***********************************************************
****************************************************************************************


import delimited "Data/Input_files/Proprietary/markit_cds_data.csv", clear 


* Keep US
keep if ticker=="USGB" 
keep if docclause=="CR" | docclause=="CR14"
keep if ccy=="EUR" 



* Only keeping 6-month and 5-year spread, and putting in bps
gen cds_us=10000*spread5y
gen cds6m_us=10000*spread6m

keep date ticker cds_us cds6m_us
split date, p("/")
destring, replace
drop date
gen date=mdy(date1, date2, date3)
duplicates drop
*

/* 
** Impute non-missing values for 6-month U.S. CDS spreads for business days in 2010 through 2014
** for which no data (use previous closing day if missing)
*/
gen cds6m_us_imp = cds6m_us
replace cds6m_us_imp = cds6m_us[_n-1] if cds6m_us_imp == . & year(date)>2009 & year(date)<2015
replace cds6m_us_imp = cds6m_us[_n-2] if cds6m_us_imp == . & year(date)>2009 & year(date)<2015
replace cds6m_us_imp = cds6m_us[_n-3] if cds6m_us_imp == . & year(date)>2009 & year(date)<2015
drop cds6m_us
rename cds6m_us_imp cds6m_us

save "Data/Created_files/cds_four_country_long.dta", replace

* Data Quality for CDS 





import delimited "Data/Input_files/Proprietary/markit_cds_data.csv", clear 


keep if ccy=="EUR" & ticker=="USGB" & docclause=="CR"

drop impliedrating
duplicates drop 

gen lambda_6m=spread6m/(1-recovery)
gen prob_6m=1-exp(-0.5*lambda_6m)

split date, p("/")
destring, replace
drop date
gen date=mdy(date1, date2, date3)
egen time_var=group(date)

tsset time_var


gen data_qual=0 if rating6m=="NR"
replace data_qual=1 if rating6m=="CC"
replace data_qual=2 if rating6m=="B"
replace data_qual=3 if rating6m=="BB"
replace data_qual=4 if rating6m=="A"
replace data_qual=5 if rating6m=="AA"

gen data_change=d.data_qual
gen fd_prob_6m=d.prob_6m


gen data_qual5y=0 if rating5y=="NR"
replace data_qual5y=1 if rating5y=="CC"
replace data_qual5y=2 if rating5y=="B"
replace data_qual5y=3 if rating5y=="BB"
replace data_qual5y=4 if rating5y=="A"
replace data_qual5y=5 if rating5y=="AA"

gen data_change5y=d.data_qual5y
joinby date using Data/Created_files/control_variables_long.dta, unmatched(master)
drop if missing(avg_ba_sp_y)

keep date data_qual* data_change* time_var

duplicates drop
rename data_qual data_qual6m
tsset time_var
foreach i in 6m 5y {
gen data`i'_5d_a=data_qual`i' 
gen missing_data`i'=cond(missing(data`i'_5d_a),1,0)
gen count_5d`i'=cond(missing(data_qual`i'),0,1)
forvalues j = 1(1)6 {
	replace data`i'_5d_a=l`j'.data_qual`i' if missing_data`i'==1 & !missing(l`j'.data_qual`i')
	replace data`i'_5d_a=data`i'_5d_a+l`j'.data_qual`i' if !missing(l`j'.data_qual`i') & !missing(data`i'_5d_a)
	replace count_5d`i'=count_5d`i'+1 if !missing(l`j'.data_qual`i')
	
}
gen data`i'_5d=data`i'_5d_a/count_5d`i'
sort time_var
gen fd_data`i'_5d=data`i'_5d-data`i'_5d[_n-1]
}

keep date data_qual6m data_change data_qual5y data_change5y data6m_5d data5y_5d fd_data*
save Data/Created_files/cds_data_qual.dta, replace



*** Creating avg bid-ask spreads for not-at-risk securities


use "Data/Created_files/bill_basic_regressions_CRSP_1990_2020.dta", clear
drop if time_to_mat_early<5
replace bid_ask_spread_yield=. if payable_early==17002 & date==16975
replace bid_ask_spread_yield=. if payable_early==12963 & date==12775


* 
gen non_at_risk=1-at_risk

drop if non_at_risk==0

bysort date: egen avg_ba_sp_y=mean(bid_ask_spread_yield)




bysort date: egen avg_norm_ba_sp=mean(normalized_bid_ask_spread)




keep date avg_norm_ba_sp avg_ba_sp_y window*

duplicates drop




joinby date using "Data/Created_files/cds_four_country_long.dta", unmatched(master)
drop _merge
joinby date using "Data/Created_files/ff_fnma_ontherunspread.dta", unmatched(master)
drop _merge
joinby date using "Data/Created_files/tedrate.dta", unmatched(master)
drop _merge
joinby date using "Data/Created_files/sveny_curve.dta", unmatched(master)
drop _merge
joinby date using "Data/Created_files/tenyearspread.dta", unmatched(master)
drop _merge
joinby date using "Data/Created_files/futures_basis.dta", unmatched(master)
drop _merge
***



* Month and Quarter End
gen month_end = 0
sort date
replace month_end = 1 if month(date) < month(date[_n+1]) 
replace month_end = 1 if month(date)==12 & month(date[_n+1])==1 


* Quarter end dummy
gen quarter_end = 0
replace quarter_end = 1 if month_end ==1 & (month(date) == 3 | month(date) == 6 | month(date) == 9 | month(date) == 12)

* Month end, but not quarter end
gen month_not_quarter_end = 0
replace month_not_quarter_end = 1 if month_end == 1 & quarter_end == 0

gen reopening=0

sort date

replace reopening=1 if day>=15 & day[_n-1]<15 & month(date)==2
replace reopening=1 if day>=15 & day[_n-1]<15 & month(date)==5
replace reopening=1 if day>=15 & day[_n-1]<15 & month(date)==8
replace reopening=1 if day>=15 & day[_n-1]<15 & month(date)==11

gen fd_reopening=reopening - reopening[_n-1]



joinby date using  "Data/Created_files/refcorp_combined.dta", unmatched(master)
gen refcorp_spread=100*(refcorp_10y - sveny10)
gen refcorp1y_spread=100*(refcorp_1y - sveny01)


sort date
foreach var of varlist avg_norm_ba_sp avg_ba_sp_y cds_us cds6m_us month_end quarter_end fnma2yr fnma5yr fnma10yr fhlmc2yr fhlmc5yr fhlmc10yr refcorp_3m refcorp_6m refcorp_1y refcorp_5y refcorp_10y tedrate refcorp_spread refcorp1y_spread onrun_svenyspread basis* {
	gen fd_`var'=`var'-`var'[_n-1]
	gen window_`var'=window*`var'
	gen fd_win_`var'=window*fd_`var'
	foreach ep in  2011  2013  {
		gen win_`ep'_`var'=window_`ep'*`var'
	}
}

foreach var of varlist avg_norm_ba_sp avg_ba_sp_y cds_us cds6m_us month_end quarter_end fnma2yr fnma5yr fnma10yr fhlmc2yr fhlmc5yr fhlmc10yr refcorp_3m refcorp_6m refcorp_1y refcorp_5y refcorp_10y tedrate refcorp_spread refcorp1y_spread onrun_svenyspread basis* {
	foreach ep in 2011  2013  {
		gen fd_win_`ep'_`var'=window_`ep'*fd_`var'
	}
}
drop _merge
save Data/Created_files/control_variables_bills.dta, replace

***********************************************************************************************************************************************
***********************************************************************************************************************************************
***********************************************************************************************************************************************

* Fannie Mae Data 


import excel "Data/Input_files/Proprietary/fannie_cusips_2010_2014.xlsx", sheet("Sheet1") firstrow clear

split Maturity, p("/") destring
rename Maturity mat_string
gen mat_date=mdy(Maturity1, Maturity2, Maturity3)
format mat_date %d

gen payable_early=mat_date

save "Data/Created_files/fannie_cusips_2010_2014.dta", replace

import excel "Data/Input_files/Proprietary/fannie_for_bloomberg.xlsx", sheet("Sheet2") firstrow clear 
replace yield_dn = "." if yield_dn=="#N/A N/A"
destring, replace
joinby CUSIP using "Data/Created_files/fannie_cusips_2010_2014.dta", unmatched(master)

gen yield_fannie=100*yield_dn
bysort payable_early (date): gen fd_yield_fannie = yield_fannie - yield_fannie[_n-1]


keep CUSIP yield_fannie fd_yield_fannie payable_early date 
* Need to move and replace when more space
save "Data/Created_files/fannie_yields_2010_2014.dta", replace


* Creating Triple Diff File
use "Data/Created_files/bill_basic_regressions_CRSP_1990_2020.dta", clear
drop if year(date)<2011
drop if year(date)>2013
drop _merge
joinby date payable_early using "Data/Created_files/fannie_yields_2010_2014.dta", unmatched(master)

bysort date payable_early: egen count=count(_n)

drop if missing(fd_yld_early)
drop if missing(ois_imputed)
rename fd_yld_early fd_yld_early1
gen fd_yld_early2=fd_ois_imputed
gen fd_yld_early3=fd_yield_fannie

keep date payable_early fd_yld_early* fd_ois_imputed fd_d_2011* fd_d_2013* fd_p_2011* fd_p_2013*


reshape long fd_yld_early , i(date payable_early) j(type)
gen fd_yld_early_ois = fd_yld_early - fd_ois_imputed
foreach var of varlist fd_d_2011_7_12 - fd_d_2013_11_7 fd_p_2011_7_21_d_2011_7_12 - fd_p_2013_11_14_d_2013_11_7  {
	gen `var'_dn=0
	replace `var'_dn=`var' if type!=2
}

foreach var of varlist fd_d_2011_7_12 - fd_d_2013_11_7 fd_p_2011_7_21_d_2011_7_12 - fd_p_2013_11_14_d_2013_11_7  {
	gen `var'_b=0
	replace `var'_b=`var' if type==1
}

egen panelvar=group(payable_early type)
egen obs=group(date)
xtset panelvar obs

save  "Data/Created_files/triple_diff_data.dta", replace


***********************************************************************************************************************************************
***********************************************************************************************************************************************
***********************************************************************************************************************************************
* Coupons Data Creation 

*********** OIS Imputation for Coupons ***********************************


import delimited "Data/Input_files/Proprietary/ois_updated.csv", clear 
forvalues i=1(1)3 {
	local j=`i'*7
	rename  ois`i'w  ois_`j'
}
forvalues i=1(1)11 {
	local j=`i'*30
	rename  ois`i'm  ois_`j'
}

forvalues i=15(3)21 {
	local j=`i'*30
	rename  ois`i'm  ois_`j'
}

forvalues i=1(1)7 {
	local j=`i'*365
	rename  ois`i'y  ois_`j'
}
rename  ois10y  ois_3650

foreach var of varlist ois_300-ois_1095 ois_1460 - ois_1825 ois_2190-ois_270 {
	replace `var'="." if `var'=="ND"
	destring `var', replace	
}

split date, p("/")
destring date*, replace
drop date 
gen date=mdy(date1, date2, date3)
format date %d 


gen ois_0=.

reshape long ois_, i(date) j(time_to_mat_early)
gen payable_early=date+time_to_mat
gen time_to_m_orig=time_to_mat_early
*Getting the right time to Maturity for each month and year
gen leap_year=0
replace leap_year=1 if year(date)==2004 | year(date)==2008 | year(date)==2012 | year(date)==2016
gen leap_year_m1=0
replace leap_year_m1=1 if year(date)==2003 | year(date)==2007 | year(date)==2011 | year(date)==2015

forvalues i=30(30)330 {
	local j=`i'/30
	replace payable_early=mdy(month(date)+`j', day(date), year(date)) if time_to_mat==`i' & month(date)+`j'<13
	replace payable_early=mdy(month(date)+`j', 30, year(date)) if time_to_mat==`i' & month(date)+`j'<13 & (month(date)+`j'==4 | month(date)+`j'==6 | month(date)+`j'==9 | month(date)+`j'==11 ) & day(date)==31
	replace payable_early=mdy(month(date)+`j', 28, year(date)) if time_to_mat==`i' & month(date)+`j'<13 & month(date)+`j'==2 & day(date)>28 & leap_year==0
	replace payable_early=mdy(month(date)+`j', 29, year(date)) if time_to_mat==`i' & month(date)+`j'<13 & month(date)+`j'==2 & day(date)>29 & leap_year==1
	replace payable_early=mdy(month(date)+`j'-12, day(date), year(date)+1) if time_to_mat==`i' & month(date)+`j'>=13
	replace payable_early=mdy(month(date)+`j'-12, 30, year(date)+1) if time_to_mat==`i' & month(date)+`j'>=13 & (month(date)+`j'-12==4 | month(date)+`j'-12==6 | month(date)+`j'-12==9 | month(date)+`j'-12==11 ) & day(date)==31	
	replace payable_early=mdy(month(date)+`j'-12, 28, year(date)+1) if time_to_mat==`i' & month(date)+`j'>=13 & month(date)+`j'-12==2 & day(date)>28 & leap_year_m1==0
	replace payable_early=mdy(month(date)+`j'-12, 29, year(date)+1) if time_to_mat==`i' & month(date)+`j'>=13 & month(date)+`j'-12==2 & day(date)>29 & leap_year_m1==1
	replace time_to_mat=payable_early-date if time_to_mat==`i'
}

forvalues j=1(1)10 {
	local i=`j'*365
	replace payable_early=mdy(month(date), day(date), year(date)+`j') if time_to_mat==`i'
	replace payable_early=mdy(month(date), 28, year(date)+`j') if time_to_mat==`i' & month(date)==2 & day(date)==29 & leap_year==1
	replace time_to_mat=payable_early-date if time_to_mat==`i'
	
}


drop if missing(ois_) & time_to_mat>0
bysort date: egen max_mat=max(time_to_mat_early)
drop if max_mat<1000


**** Creating the imputed OIS values
tsset date time_to_mat_early
tsfill
replace payable_early=date+time_to_mat

gen ttm_sq=time_to_mat*time_to_mat

gen ttm_cu=time_to_mat^3
gen ttm_qu=time_to_mat^4




*** Creating 5-year point
gen five_yeara=0
replace five_yeara=1 if !missing(ois_) & time_to_mat>1800 & time_to_mat<1900
gen five_year_time=five_yeara*time_to_mat
bysort date: egen time_give_year=max(five_year_time)

*** Running regression on up to five year
regress ois_ i.date##(c.time_to_mat c.ttm_sq ) if time_to_mat<=time_give_year
predict predicted1 if time_to_mat<=time_give_year

regress ois_ i.date##(c.time_to_mat c.ttm_sq ) 
predict predicted2 if time_to_mat>time_give_year




gen ois_predicted=predicted1
replace ois_predicted=predicted2 if time_to_mat>time_give_year


gen ois_imputed=ois_predicte*100
drop  time_to_mat*

compress
sort date

gen five_year_point=0
replace five_year_point=1 if five_year_time>0

gen has_ois=0
replace has_ois=1 if !missing(ois_)
gen has_ois_pa=payable_earl*has_ois
bysort date: egen max_ois=max(has_ois_pa)

drop has_ois has_ois_pa



save "Data/Created_files/OIS_imputation_coupons_all_years.dta", replace


*********** Main Coupons File ********************************************


import delimited "Data/Input_files/Proprietary/crsp_treasury_1990_2019_for_submission.csv", clear 

split caldt, p("/")
split tmatdt, p("/")
split tdatdt, p("/")


destring, replace
gen date=mdy(caldt1, caldt2, caldt3)
gen payable_early=mdy(tmatdt1, tmatdt2, tmatdt3)
gen tdated=mdy(tdatdt1, tdatdt2, tdatdt3)

drop if date<tdated & !missing(tdated)
joinby tcusip using "Data/Created_files/bill_type.dta", unmatched(master)
drop _merge


* keeping ony coupons
keep if itype<3

gen year=year(date)
gen time_to_mat=payable_early - date
gen matdt=payable_early
gen qdat=date
gen datdt=tdated

************ Next Coupon Code *********************




gen mat_month=month(matdt)
gen mat_day=day(matdt)
gen mat_year=year(matdt)

gen this_year_leap=0
forvalues i=1992(4)2020 {
	replace this_year_leap=1 if year(qdat)==`i'
}

gen before_mat_month=0
replace before_mat_month=1 if month(qdat)<mat_month
replace before_mat_month=1 if month(qdat)==mat_month & day(qdat)<=mat_day & mat_day==15
replace before_mat_month=1 if month(qdat)==mat_month & mat_day>15
replace before_mat_month=0 if month(qdat)<mat_month-6
replace before_mat_month=0 if month(qdat)==mat_month-6 & day(qdat)<=mat_day & mat_day==15
replace before_mat_month=0 if month(qdat)==mat_month-6 & mat_day>15
gen next_coupon=mdy(mat_month, mat_day, year(qdat)) if before_mat_month==1
replace next_coupon=mdy(mat_month, 29, year(qdat)) if before_mat_month==1 & mat_month==2 & this_year_leap==1 & mat_day>15
replace next_coupon=mdy(mat_month, 28, year(qdat)) if before_mat_month==1 & mat_month==2 & this_year_leap==0 & mat_day>15

replace next_coupon=mdy(mat_month-6, mat_day, year(qdat)) if before_mat_month==0 & month(qdat)<mat_month-5
replace next_coupon=mdy(mat_month-6, 28, year(qdat)) if before_mat_month==0 & month(qdat)<mat_month-5 & mat_month==8 & mat_day>15
replace next_coupon=mdy(mat_month-6, 29, year(qdat)) if before_mat_month==0 & month(qdat)<mat_month-5 & mat_month==8 & this_year_leap==1 & mat_day>15
replace next_coupon=mdy(mat_month-6, 30, year(qdat)) if before_mat_month==0 & month(qdat)<mat_month-5 & (mat_month==10 | mat_month==12 )  & mat_day>15
replace next_coupon=mdy(mat_month-6, 31, year(qdat)) if before_mat_month==0 & month(qdat)<mat_month-5 & (mat_month==7 | mat_month==9 | mat_month==11 )  & mat_day>15

gen after_mat_month=0
replace after_mat_month=1 if month(qdat)>mat_month
replace after_mat_month=1 if month(qdat)==mat_month & day(qdat)>mat_day & mat_day==15
replace after_mat_month=0 if month(qdat)>mat_month+6
replace after_mat_month=0 if month(qdat)==mat_month+6 & day(qdat)>mat_day & mat_day==15
replace next_coupon=mdy(mat_month+6,mat_day, year(qdat)) if after_mat_month==1
replace next_coupon=mdy(mat_month+6,30, year(qdat)) if after_mat_month==1 & (mat_month==3 | mat_month==5) & mat_day>15
replace next_coupon=mdy(mat_month+6,31, year(qdat)) if after_mat_month==1 & (mat_month==1 | mat_month==2 | mat_month==4 | mat_month==6) & mat_day>15

gen next_year_leap=0
forvalues i=1991(4)2019 {
	replace next_year_leap=1 if year(qdat)==`i'
}


gen more_after_month=0
replace more_after_month=1 if month(qdat)>mat_month+6
replace more_after_month=1 if month(qdat)==mat_month+6 & day(qdat)>mat_day & mat_day==15
replace next_coupon=mdy(mat_month, mat_day, year(qdat)+1) if more_after_month==1
replace next_coupon=mdy(mat_month, 28, year(qdat)+1) if more_after_month==1 & next_year_leap==0 & mat_month==2 & mat_day==29
replace next_coupon=mdy(mat_month, 29, year(qdat)+1) if more_after_month==1 & next_year_leap==1 & mat_month==2 & mat_day==28


gen after_month_following_year=0
replace after_month_following_year=1 if month(qdat)>mat_month & mat_month>6
replace after_month_following_year=1 if month(qdat)==mat_month & day(qdat)>mat_day & mat_month>6 & mat_day==15
replace next_coupon=mdy(mat_month-6, mat_day, year(qdat)+1) if after_month_following_year==1
replace next_coupon=mdy(mat_month-6, 28, year(qdat)+1) if after_month_following_year==1 & mat_month==8 & mat_day>15 & next_year_leap==0
replace next_coupon=mdy(mat_month-6, 29, year(qdat)+1) if after_month_following_year==1 & mat_month==8 & mat_day>15 & next_year_leap==1
replace next_coupon=mdy(mat_month-6, 30, year(qdat)+1) if after_month_following_year==1 & (mat_month==10 | mat_month==12) & mat_day>15
replace next_coupon=mdy(mat_month-6, 31, year(qdat)+1) if after_month_following_year==1 & (mat_month==7 | mat_month==9 | mat_month==11) & mat_day>15



********** Now creating previous_coupon
** The 15th only
gen previous_coupon=mdy(month(next_coupon)+6, day(next_coupon), year(next_coupon)-1) if mdy(month(next_coupon)+6, day(next_coupon), year(next_coupon)-1)>datdt+30 & day(next_coupon)==15 & month(next_coupon)<=6
replace previous_coupon=mdy(month(next_coupon)-6, day(next_coupon), year(next_coupon)) if mdy(month(next_coupon)-6, day(next_coupon), year(next_coupon))>datdt+30 & day(next_coupon)==15 & month(next_coupon)>6


gen leap_year=0
forvalues i=1992(4)2020 {
	replace leap_year=1 if year(next_coupon)==`i'
}
** Doing the end of month ones individually
replace previous_coupon=mdy(1, 31, year(next_coupon)) if mdy(1, 31, year(next_coupon)) >datdt+30 & month(next_coupon)==7 & day(next_coupon)>15 
replace previous_coupon=mdy(2, 28, year(next_coupon)) if mdy(2, 28, year(next_coupon)) >datdt+30 & month(next_coupon)==8 & day(next_coupon)>15  & leap_year==0
replace previous_coupon=mdy(2, 29, year(next_coupon)) if mdy(2, 29, year(next_coupon)) >datdt+30 & month(next_coupon)==8 & day(next_coupon)>15  & leap_year==1
replace previous_coupon=mdy(3, 31, year(next_coupon)) if mdy(3, 31, year(next_coupon)) >datdt+30 & month(next_coupon)==9 & day(next_coupon)>15 
replace previous_coupon=mdy(4, 30, year(next_coupon)) if mdy(4, 30, year(next_coupon)) >datdt+30 & month(next_coupon)==10 & day(next_coupon)>15 
replace previous_coupon=mdy(5, 31, year(next_coupon)) if mdy(5, 31, year(next_coupon)) >datdt+30 & month(next_coupon)==11 & day(next_coupon)>15 
replace previous_coupon=mdy(6, 30, year(next_coupon)) if mdy(6, 30, year(next_coupon)) >datdt+30 & month(next_coupon)==12 & day(next_coupon)>15 
replace previous_coupon=mdy(7, 31, year(next_coupon)-1) if mdy(7, 31, year(next_coupon)-1) >datdt+30 & month(next_coupon)==1 & day(next_coupon)>15 
replace previous_coupon=mdy(8, 31, year(next_coupon)-1) if mdy(8, 31, year(next_coupon)-1) >datdt+30 & month(next_coupon)==2 & day(next_coupon)>15 
replace previous_coupon=mdy(9, 30, year(next_coupon)-1) if mdy(9, 30, year(next_coupon)-1) >datdt+30 & month(next_coupon)==3 & day(next_coupon)>15 
replace previous_coupon=mdy(10, 31, year(next_coupon)-1) if mdy(10, 31, year(next_coupon)-1) >datdt+30 & month(next_coupon)==4 & day(next_coupon)>15 
replace previous_coupon=mdy(11, 30, year(next_coupon)-1) if mdy(11, 30, year(next_coupon)-1) >datdt+30 & month(next_coupon)==5 & day(next_coupon)>15 
replace previous_coupon=mdy(12, 31, year(next_coupon)-1) if mdy(12, 31, year(next_coupon)-1) >datdt+30 & month(next_coupon)==6 & day(next_coupon)>15 



****************************************************************************


gen date_bus=bofd("treasdays", date)
foreach var of varlist matdt next_coupon {
gen `var'_pl1=`var'+1
gen `var'_pl2=`var'+2
gen `var'_pl3=`var'+3
gen `var'_bus=bofd("treasdays", `var')
gen `var'_bus_pl1=bofd("treasdays", `var'_pl1)
gen `var'_bus_pl2=bofd("treasdays", `var'_pl2)
gen `var'_bus_pl3=bofd("treasdays", `var'_pl3)
replace `var'_bus=`var'_bus_pl1 if missing(`var'_bus) & !missing(`var'_bus_pl1)
replace `var'_bus=`var'_bus_pl2 if missing(`var'_bus) & !missing(`var'_bus_pl2)
replace `var'_bus=`var'_bus_pl3 if missing(`var'_bus) & !missing(`var'_bus_pl3)
}

*********************************************************************
* compute the timing of the next coupon and maturity buckets 


gen mat_0_6mo=0
replace mat_0_6mo=1 if next_coupon==matdt
gen mat_6mo_1yr=0
replace mat_6mo_1yr=1 if next_coupon!=matdt & year(matdt)==year(qdat)
replace mat_6mo_1yr=1 if next_coupon!=matdt & year(matdt)==year(qdat)+1 & month(qdat)>month(matdt)
replace mat_6mo_1yr=1 if next_coupon!=matdt & year(matdt)==year(qdat)+1 & month(qdat)==month(matdt) & day(qdat)>day(matdt)

gen mat_1_2=0
replace mat_1_2=1 if mat_6mo_1yr==0 & year(matdt)==year(qdat)+1 & month(matdt)>month(qdat)
replace mat_1_2=1 if mat_6mo_1yr==0 & year(matdt)==year(qdat)+1 & month(matdt)==month(qdat) & day(matdt)>=day(qdat)
replace mat_1_2=1 if year(matdt)==year(qdat)+2 & month(qdat)==month(matdt) & day(qdat)>day(matdt)
replace mat_1_2=1 if year(matdt)==year(qdat)+2 & month(matdt)<month(qdat)
replace mat_1_2=1 if year(matdt)==year(qdat)+2 & month(matdt)==month(qdat) & day(matdt)<day(qdat)

forvalues i=3(1)31 {
	local j=`i'-1
	local k=`i'-2
	gen mat_`j'_`i'=0
	replace mat_`j'_`i'=1 if mat_`k'_`j'==0 & year(matdt)==year(qdat)+`j' & month(matdt)>month(qdat)
	replace mat_`j'_`i'=1 if mat_`k'_`j'==0 & year(matdt)==year(qdat)+`j'& month(matdt)==month(qdat) & day(matdt)>=day(qdat)
	replace mat_`j'_`i'=1 if year(matdt)==year(qdat)+`i' & month(qdat)==month(matdt) & day(qdat)>day(matdt)
	replace mat_`j'_`i'=1 if year(matdt)==year(qdat)+`i' & month(matdt)<month(qdat)
	replace mat_`j'_`i'=1 if year(matdt)==year(qdat)+`i' & month(matdt)==month(qdat) & day(matdt)<day(qdat)
	}




gen years_to_maturity=0.5 if mat_0_6mo==1
replace years_to_maturity=1 if mat_6mo_1yr==1
forvalues i=2(1)31 {
	local j=`i'-1
	replace years_to_maturity=`i' if mat_`j'_`i'==1
}







gen time_to_mat_business=matdt_bus-date_bus
gen couprt=tcouprt
gen time_to_mat_bus_couprt = time_to_mat_business*couprt

* generating maturity buckets based on business days 
gen mat_b_less_than_2=0
replace mat_b_less_than_2=1 if years_to_mat<2
gen mat_b_3=0
replace mat_b_3=1 if years_to_mat==2
gen mat_b_4_5=0
replace mat_b_4_5=1 if years_to_mat==3 | years_to_mat==4
gen mat_b_6_7=0
replace mat_b_6_7=1 if years_to_mat==5 | years_to_mat==6
gen mat_b_8_10=0
replace mat_b_8_10=1 if years_to_mat==7 | years_to_mat==8  | years_to_mat==9
gen mat_b_11_20=0
replace mat_b_11_20=1 if years_to_mat>=10 & years_to_mat<20
gen mat_b_21_30=0
replace mat_b_21_30=1 if years_to_mat>=20 

gen bus_mat_sq=time_to_mat_business^2
gen bus_mat_sq_couprt=couprt*time_to_mat_business^2

foreach var of varlist mat_b_less_than_2-mat_b_21_30 {
	gen `var'_time_bus=`var'*time_to_mat_business
	gen `var'_time_bus_sq=`var'*bus_mat_sq
	}

* interacting piecewise time to mat business buckets with coupon rate 
foreach var of varlist mat_b_less_than_2-mat_b_21_30 {
	gen `var'_t_bus_crt=`var'*time_to_mat_business*couprt
	gen `var'_t_bus_sq_crt=`var'*bus_mat_sq*couprt
	}

	
gen time_to_mat_sq=time_to_mat^2

foreach var of varlist mat_b_less_than_2-mat_b_21_30 {
	gen `var'_time=`var'*time_to_mat
	gen `var'_time_sq=`var'*time_to_mat*time_to_mat
	}


* generating original tenor 
gen original_tenor_days=matdt-datdt
gen original_tenor=2 if original_tenor_days>=700 & original_tenor_days<=800
replace original_tenor=3 if original_tenor_days>=1000 & original_tenor_days<=1200
replace original_tenor=5 if original_tenor_days>=1800 & original_tenor_days<=1900
replace original_tenor=7 if original_tenor_days>=2500 & original_tenor_days<=2600
replace original_tenor=10 if original_tenor_days>=3600 & original_tenor_days<=3700
replace original_tenor=30 if original_tenor_days>=10000 & original_tenor_days<=12000




gen time_to_next_coupon_business=next_coupon_bus-date_bus







* generating annual yield 
* yield in CRSP data is daily promised value 
* deliberately multiplying by 100 twice to get in basis points
gen yld_early=((1+tdyld)^365-1)*100*100

* generating bid ask spread 
gen bid_ask_spread =  tdask - tdbid 
* generating percent bid ask spread
gen percent_bid_ask_spread = ((tdask - tdbid )/tdbid)*100




********************************************* Date/CUSIP Fixed Effects: Pincipal & Interest ************************************************************************

gen payable_pi = . 
replace payable_pi = 1 if next_coupon==payable_early
replace payable_pi = 0 if next_coupon!=payable_early




* creating at risk day dummies

* 1996 Episode
local min_1996 = mdy(11,14,1995)
local max_1996 = mdy(4,29,1996)
* 2002 Episode
local min_2002 = mdy(5,15,2002)
local max_2002 = mdy(7,28,2002)
* 2003 Episode
local min_2003 = mdy(2,19,2003)
local max_2003 = mdy(6,27,2003)
* 2004 Episode
local min_2004 = mdy(10,13,2004)
local max_2004 = mdy(12,15,2004)
* 2006 Episode
local min_2006 = mdy(2,18,2006)
local max_2006 = mdy(4,20,2006)
* 2011 Episode
local min_2011 = mdy(5,17,2011)
local max_2011 = mdy(9,2,2011)
* 2012 Episode
local min_2012 = mdy(12,30,2012)
local max_2012 = mdy(4,1,2013)
* 2013 Episode
local min_2013 = mdy(5,19,2013)
local max_2013 = mdy(11,17,2013)
* 2014 Episode
local min_2014 = mdy(2,9,2014)
local max_2014 = mdy(3,27,2014)
* 2015 Episode
local min_2015 = mdy(3,15,2015)
local max_2015 = mdy(12,5,2015)
* 2017 Episode
local min_2017 = mdy(3,15,2017)
local max_2017 = mdy(10,29,2017)
* 2018 Episode
local min_2018 = mdy(12,7,2017)
local max_2018 = mdy(3,28,2018)
* 2019 Episode
local min_2019 = mdy(3,3,2019)
local max_2019 = mdy(10,1,2019)


* Create At-risk securities and date dummies during episodes
foreach ep in 1996 2002 2003 2004 2006 2011 2012 2013 2014 2015 2017 2018 2019 {
	local p_start = `max_`ep'' - 46
	local p_end = `max_`ep'' + 10
	local p_date= `max_`ep'' - 30
	gen at_risk_p_`ep'=0
	replace at_risk_p_`ep'=1 if payable_early>`p_start' & payable_early<`p_end'
	gen at_risk_i_`ep'=0
	replace at_risk_i_`ep'=1 if next_coupon>`p_start' & next_coupon<`p_end'
	local first=`max_`ep''- 50
	local last=`max_`ep''- 20
forvalues i=`first'/`last' {
	local month=month(`i')
	local day=day(`i')
	local year=year(`i')
	gen d_`year'_`month'_`day'=0 
	replace d_`year'_`month'_`day'=1 if date==`i'
	su d_`year'_`month'_`day', meanonly
	replace d_`year'_`month'_`day'=. if `r(min)'==`r(max)'
	missings dropvars d_`year'_`month'_`day', force
}
}

egen at_risk_p=rowmax(at_risk_p*)
egen at_risk_i=rowmax(at_risk_i*)

* Create date - payable dummies for at-risk securities
foreach ep in 1996 2002 2003 2004 2006 2011 2012 2013 2014 2015 2017 2018 2019 {
	local first=`max_`ep''- 50
	local last=`max_`ep'' - 20
	local p_start = `max_`ep'' - 46
	local p_end = `max_`ep'' + 10
	forvalues i=`first'/`last' {
		local date_month=month(`i')
		local date_day=day(`i')
		local date_year=year(`i')
		forvalues j=`p_start'/`p_end' {
			local pay_month=month(`j')
			local pay_day=day(`j')
			local pay_year=year(`j')
			gen p_`pay_year'_`pay_month'_`pay_day'_d_`date_year'_`date_month'_`date_day'=0
			replace p_`pay_year'_`pay_month'_`pay_day'_d_`date_year'_`date_month'_`date_day'=1 if date==`i' & payable_early==`j' & at_risk_p_`ep'==1
			su p_`pay_year'_`pay_month'_`pay_day'_d_`date_year'_`date_month'_`date_day', meanonly
			replace p_`pay_year'_`pay_month'_`pay_day'_d_`date_year'_`date_month'_`date_day'=. if `r(min)'==`r(max)'
			missings dropvars p_`pay_year'_`pay_month'_`pay_day'_d_`date_year'_`date_month'_`date_day', force
			gen i_`pay_year'_`pay_month'_`pay_day'_d_`date_year'_`date_month'_`date_day'=0
			replace i_`pay_year'_`pay_month'_`pay_day'_d_`date_year'_`date_month'_`date_day'=1 if date==`i' & next_coupon==`j' & at_risk_i_`ep'==1
			su i_`pay_year'_`pay_month'_`pay_day'_d_`date_year'_`date_month'_`date_day', meanonly
			replace i_`pay_year'_`pay_month'_`pay_day'_d_`date_year'_`date_month'_`date_day'=. if `r(min)'==`r(max)'
			missings dropvars i_`pay_year'_`pay_month'_`pay_day'_d_`date_year'_`date_month'_`date_day', force
		}
	}
}



joinby date payable_early using "Data/Created_files/OIS_imputation_coupons_all_years.dta", unmatched(master)


gen ba_type=0
replace ba_type=1 if  date<mdy(4,1,1991)
replace ba_type=2 if date>=mdy(4,1,1991) & date<mdy(10,16,1996)
replace ba_type=3 if date>=mdy(10,16,1996) & date<mdy(10,21,1998)
replace ba_type=4 if date>=mdy(10,21,1998) & date<mdy(2,1,2009)
replace ba_type=5 if date>=mdy(2,1,2009) & date<mdy(3,7,2012)
replace ba_type=6 if date>=mdy(3,7,2012) & date<mdy(10,26,2015)
replace ba_type=7 if date>=mdy(10,26,2015)



gen normalized_bid_ask_spread=.
forvalues i=1/7 {
	disp `i'
	qui su bid_ask_spread if ba_type==`i'
	disp `r(mean)' 
	disp `r(sd)'
	replace normalized_bid_ask_spread= (bid_ask_spread - `r(mean)')/`r(sd)' if ba_type==`i'
}


foreach ep in 1996 2002 2003 2004 2006 2011 2013 2014 2015 2017 2018 2019 {
	egen window_`ep'=rowmax(d_`ep'_*)
}
gen window_2012=0
replace window_2012=window_2013 if year(date)==2013 & month(date)<6
replace window_2013=0 if year(date)==2013 & month(date)<6

egen window=rowmax(d_*)

save "Data/Created_files/coupons_basic_regressions_CRSP_1990_2020.dta", replace


***********************************************************************************************************************
***********************************************************************************************************************

******** Coupon Control Variables **************


*** Creating avg bid-ask spreads for not-at-risk securities


drop if time_to_mat<5


* 
egen at_risk=rowmax(at_risk_i at_risk_p)
gen non_at_risk=1-at_risk

drop if non_at_risk==0

bysort date: egen avg_ba_sp=mean(bid_ask_spread)




bysort date: egen avg_norm_ba_sp=mean(normalized_bid_ask_spread)




keep date avg_norm_ba_sp avg_ba_sp  window*

duplicates drop



joinby date using "Data/Created_files/cds_four_country_long.dta", unmatched(master)
drop _merge
joinby date using "Data/Created_files/ff_fnma_ontherunspread.dta", unmatched(master)
drop _merge
joinby date using "Data/Created_files/tedrate.dta", unmatched(master)
drop _merge
joinby date using "Data/Created_files/sveny_curve.dta", unmatched(master)
drop _merge
joinby date using "Data/Created_files/tenyearspread.dta", unmatched(master)
drop _merge
joinby date using "Data/Created_files/futures_basis.dta", unmatched(master)
drop _merge
joinby date using  "Data/Created_files/refcorp_combined.dta", unmatched(master)


* Month and Quarter End
gen month_end = 0
sort date
replace month_end = 1 if month(date) < month(date[_n+1]) 
replace month_end = 1 if month(date)==12 & month(date[_n+1])==1 


* Quarter end dummy
gen quarter_end = 0
replace quarter_end = 1 if month_end ==1 & (month(date) == 3 | month(date) == 6 | month(date) == 9 | month(date) == 12)

* Month end, but not quarter end
gen month_not_quarter_end = 0
replace month_not_quarter_end = 1 if month_end == 1 & quarter_end == 0



gen reopening=0

sort date

replace reopening=1 if day>=15 & day[_n-1]<15 & month(date)==2
replace reopening=1 if day>=15 & day[_n-1]<15 & month(date)==5
replace reopening=1 if day>=15 & day[_n-1]<15 & month(date)==8
replace reopening=1 if day>=15 & day[_n-1]<15 & month(date)==11

gen fd_reopening=reopening - reopening[_n-1]


gen refcorp_spread=100*(refcorp_10y - sveny10)
drop _merge


sort date
foreach var of varlist avg_norm_ba_sp avg_ba_sp  cds_us month_end quarter_end fnma2yr fnma5yr fnma10yr fhlmc2yr fhlmc5yr fhlmc10yr  refcorp_3m refcorp_6m refcorp_1y refcorp_5y refcorp_10y tedrate refcorp_spread onrun_svenyspread basis*  {
	gen fd_`var'=`var'-`var'[_n-1]
	gen window_`var'=window*`var'
	gen fd_win_`var'=window*fd_`var'
	foreach ep in 1996 2002 2003 2004 2006 2011 2012 2013 2014 2015 2017 2018 2019 {
		gen win_`ep'_`var'=window_`ep'*`var'
	}
}

foreach var of varlist avg_norm_ba_sp avg_ba_sp  cds_us month_end quarter_end fnma2yr fnma5yr fnma10yr fhlmc2yr fhlmc5yr fhlmc10yr  refcorp_3m refcorp_6m refcorp_1y refcorp_5y refcorp_10y tedrate refcorp_spread onrun_svenyspread basis* {
	foreach ep in 1996 2002 2003 2004 2006 2011 2012 2013 2014 2015 2017 2018 2019 {
		gen fd_win_`ep'_`var'=window_`ep'*fd_`var'
	}
}

save Data/Created_files/control_variables_long_coupons.dta, replace

*********************************************************************************************************************************************************
*********************************************************************************************************************************************************
*********************************************************************************************************************************************************

*********** Bills Coupon Matched Dataset



use "Data/Created_files/bill_basic_regressions_CRSP_1990_2020.dta", clear
drop _merge

gen leap_year=0
replace leap_year=1 if year(payable_early)==1992
replace leap_year=1 if year(payable_early)==1996
replace leap_year=1 if year(payable_early)==2000
replace leap_year=1 if year(payable_early)==2004
replace leap_year=1 if year(payable_early)==2008
replace leap_year=1 if year(payable_early)==2012
replace leap_year=1 if year(payable_early)==2016
replace leap_year=1 if year(payable_early)==2020
replace leap_year=1 if year(payable_early)==2024
replace leap_year=1 if year(payable_early)==2028
replace leap_year=1 if year(payable_early)==2032

gen coupon_match_date=mdy(month(payable_early),15,year(payable_early)) if day(payable_early)>11 & day(payable_early)<19




replace coupon_match_date=mdy(month(payable_early),31,year(payable_early)) if day(payable_early)>27 & !missing(payable_early) 
replace coupon_match_date=mdy(month(payable_early),30,year(payable_early)) if day(payable_early)>26 & !missing(payable_early) & month(payable_early)==4 
replace coupon_match_date=mdy(month(payable_early),30,year(payable_early)) if day(payable_early)>26 & !missing(payable_early) & month(payable_early)==6
replace coupon_match_date=mdy(month(payable_early),30,year(payable_early)) if day(payable_early)>26 & !missing(payable_early) & month(payable_early)==9
replace coupon_match_date=mdy(month(payable_early),30,year(payable_early)) if day(payable_early)>26 & !missing(payable_early) & month(payable_early)==11
replace coupon_match_date=mdy(month(payable_early),28,year(payable_early)) if day(payable_early)>24 & !missing(payable_early) & month(payable_early)==2 & leap_year==0
replace coupon_match_date=mdy(month(payable_early),29,year(payable_early)) if day(payable_early)>25 & !missing(payable_early) & month(payable_early)==2 & leap_year==1

replace coupon_match_date=mdy(month(payable_early)-1,31,year(payable_early)) if day(payable_early)<4 
replace coupon_match_date=mdy(12,31,year(payable_early)-1) if day(payable_early)<4 & month(payable_early)==1

replace coupon_match_date=mdy(month(payable_early)-1,30,year(payable_early)) if day(payable_early)<4 & month(payable_early)==5
replace coupon_match_date=mdy(month(payable_early)-1,30,year(payable_early)) if day(payable_early)<4 & month(payable_early)==7
replace coupon_match_date=mdy(month(payable_early)-1,30,year(payable_early)) if day(payable_early)<4 & month(payable_early)==10
replace coupon_match_date=mdy(month(payable_early)-1,30,year(payable_early)) if day(payable_early)<4 & month(payable_early)==12

replace coupon_match_date=mdy(month(payable_early)-1,28,year(payable_early)) if day(payable_early)<4 & month(payable_early)==3 & leap_year==0
replace coupon_match_date=mdy(month(payable_early)-1,29,year(payable_early)) if day(payable_early)<4 & month(payable_early)==3 & leap_year==1

keep date payable_early yld_early ois_imputed fd_yld_early fd_ois_imputed coupon_match_date
drop if missing(coupon_match_date)

rename payable_early bill_pay_date
rename yld_early yld_early_bill
rename fd_yld_early fd_yld_early_bill
rename fd_ois_imputed fd_ois_bill
rename ois_imputed ois_bill

save "Data/Created_files/bills_coupon_match.dta", replace







use "Data/Created_files/coupons_basic_regressions_CRSP_1990_2020.dta", clear
drop _merge
joinby date using Data/Created_files/control_variables_long_coupons.dta, unmatched(master)
drop _merge
rename fd_avg_norm_ba_sp  fd_avg_norm_ba_coup
rename fd_win_2011_avg_norm_ba_sp fd_win_2011_avg_norm_ba_coup
rename fd_win_2012_avg_norm_ba_sp fd_win_2012_avg_norm_ba_coup
rename fd_win_2013_avg_norm_ba_sp fd_win_2013_avg_norm_ba_coup

joinby date using Data/Created_files/control_variables_long.dta, unmatched(master)

drop date_bus 
egen date_bus = group(date)

xtset kytreasno date_bus
foreach var of varlist yld_early ois_imputed d_* p_*  i_* normalized_bid_ask_spread {
	gen fd_`var'=d.`var'
}


foreach i in 1996 2002 2003 2004 2006 2011 2012 2013 2014 2015 2017 2018 2019 {

gen fd_win_`i'_norm=window_`i'*fd_normalized_bid_ask_spread
}



forvalues i=1990(1)2019 {
	gen fd_ois_imputed_`i'=0
	replace fd_ois_imputed_`i'=fd_ois_imputed if year==`i'
}




foreach var of varlist avg_norm_ba_sp tedrate refcorp_spread onrun_svenyspread  cds_us {
	gen fd_win_o_`var'=fd_win_2011_`var'+fd_win_2013_`var'
}


gen time_dow=time_to_mat
replace time_dow=182 if time_to_mat>182
gen dow=dow(date)


gen coupon_match_date=payable_early
drop _merge
joinby date coupon_match_date using Data/Created_files/bills_coupon_match.dta, unmatched(master)

gen fd_yld_diff = fd_yld_early - fd_yld_early_bill 
gen fd_ois_diff = fd_ois_imputed - fd_ois_bill 

drop if missing(fd_yld_diff)
keep if year(date)>2010 & year(date)<2014





bysort at_risk_p date: egen avg_coup_norm_ba_a=mean(normalized_bid_ask_spread)
replace avg_coup_norm_ba_a=. if at_risk_p==1
bysort date: egen avg_coup_norm_ba=max(avg_coup_norm_ba_a)
egen panelvar=group(kytreasno)
egen obs=group(date)
xtset panelvar obs

gen fd_avg_coup_norm_ba = d.avg_coup_norm_ba
gen fd_win_2011_avg_coup_norm_ba=avg_coup_norm_ba*window_2011
gen fd_win_2013_avg_coup_norm_ba=avg_coup_norm_ba*window_2013

gen yld_diff= yld_early - yld_early_bill
gen fd_yld_early_ois = fd_yld_early - fd_ois_imputed
gen fd_yld_early_bill_ois = fd_yld_early_bill - fd_ois_bill
gen fd_yld_diff_ois =  fd_yld_early_ois - fd_yld_early_bill_ois

save "Data/Created_files/bills_coupon_match.dta", replace


*** Refcorp Spreads 



import delimited "Data/Input_files/Public/constant_maturity.csv", clear 
split date, p("/") destring
drop date 
gen date=mdy(date1, date2, date3)
joinby date using "Data/Created_files/refcorp_combined.dta", unmatched(master)
drop if year(date)<2011
drop if year(date)>2013
drop if missing(riflgfcm03_nb)

gen refcorp_spread91 = 100*(refcorp_3m - riflgfcm03_nb)
gen refcorp_spread182 = 100*(refcorp_6m - riflgfcm06_nb)
gen refcorp_spread365 = 100*(refcorp_1y - riflgfcy01_nb)
gen refcorp_spread1825 = 100*(refcorp_5y - riflgfcy05_nb)
gen refcorp_spread3650 = 100*(refcorp_10y - riflgfcy10_nb)

keep date refcorp_spread*



* Key Dates

* 2011 Episode
local key_2011 = mdy(8,2,2011)
* 2013 Episode
local key_2013 = mdy(10,17,2013)


* Create date dummies during episodes
foreach ep in 2011 2013  {
	local first=`key_`ep''- 21
	local last=`key_`ep''+ 21
forvalues i=`first'/`last' {
	local month=month(`i')
	local day=day(`i')
	local year=year(`i')
	gen d_`year'_`month'_`day'=0 
	replace d_`year'_`month'_`day'=1 if date==`i'
	su d_`year'_`month'_`day', meanonly
	replace d_`year'_`month'_`day'=. if `r(min)'==`r(max)'
	missings dropvars d_`year'_`month'_`day', force
}
}


egen date_num = group(date)
tsset date_num 
foreach var of varlist d_2011* d_2013* refcorp_spread* {
	gen fd_`var'=d.`var'
}

reshape long refcorp_spread fd_refcorp_spread, i(date) j(term)



xtset term date_num 

save "Data/Created_files/refcorp_spread_data.dta", replace 
**********************************************************************************************************************
**********************************************************************************************************************
**********************************************************************************************************************
                                                 * Tables *

***************** Table 1 ********************************************************************************************


use "Data/Created_files/bill_basic_regressions_CRSP_1990_2020.dta", clear
drop _merge

gen window_big_2011=0
replace window_big_2011=1 if date>mdy(5,15,2011) & date<mdy(10,20,2011)
gen window_big_2013=0
replace window_big_2013=1 if date>mdy(5,19,2013) & date<mdy(3,17,2014)

gen yld_early_ois = yld_early - ois_imputed

* Bills
log using "Output/summary_stats.log", replace
foreach var of varlist yld_early ois_imputed yld_early_ois normalized_bid_ask_spread yld_early_ois {
	display "2011 to 2013"
	sum `var' if year(date)>2010 & year(date)<2014
	display "In Window 2011 and 2013"
	sum `var' if window_2011==1 | window_2013==1
	display "2010 to 2014"
	sum `var' if year(date)>2009 & year(date)<2015
	display "In Big Window 2011 and 2013"
	sum `var' if window_big_2011==1 | window_big_2013==1
}
log close


* Discount Notes

use  "Data/Created_files/bill_basic_regressions_CRSP_1990_2020.dta", clear
drop _merge 
joinby payable_early date using "Data/Created_files/fannie_yields_2010_2014.dta", unmatched(both)

gen window_big_2011=0
replace window_big_2011=1 if date>mdy(5,15,2011) & date<mdy(10,20,2011)
gen window_big_2013=0
replace window_big_2013=1 if date>mdy(5,19,2013) & date<mdy(3,17,2014)

gen fannie_spread =  yield_fannie - yld_early 
*gen freddie_spread = freddie_yld - yld_early  

bysort payable_early (date): gen fd_fannie_spread = fannie_spread - fannie_spread[_n - 1]



log using "Output/summary_stats.log", append

	display " 2011 to 2013"
	sum fannie_spread if year(date)>2010 & year(date)<2014 
	display " 2010 to 2014"
	sum fannie_spread if year(date)>2009 & year(date)<2015 
	display " In Window 2011 and 2013"
	sum fannie_spread if (window_2011==1 | window_2013==1) 
	display "In Big Window 2011 and 2013"
	sum fannie_spread if (window_big_2011==1 | window_big_2013==1) 

	
	display " 2011 to 2013"
	sum yield_fannie if year(date)>2010 & year(date)<2014 
	display " 2010 to 2014"
	sum yield_fannie if year(date)>2009 & year(date)<2015 
	display " In Window 2011 and 2013"
	sum yield_fannie if (window_2011==1 | window_2013==1) 
	display "In Big Window 2011 and 2013"
	sum yield_fannie if (window_big_2011==1 | window_big_2013==1) 
log close


* Refcorp Spread 
use "Data/Created_files/refcorp_spread_data.dta", clear
foreach ep in 2011 2013 {
	egen window_`ep'=rowmax(d_`ep'_*)
}


egen window=rowmax(d_*)

gen window_big_2011=0
replace window_big_2011=1 if date>mdy(5,15,2011) & date<mdy(10,20,2011)
gen window_big_2013=0
replace window_big_2013=1 if date>mdy(5,19,2013) & date<mdy(3,17,2014)

log using "Output/summary_stats.log", append
sum refcorp_spread if year(date)>2010 & year(date)<2014 & (term==91 | term==182)
sum refcorp_spread if year(date)>2010 & year(date)<2014 & (term==91 | term==182) & (window_2011==1 | window_2013==1)
sum refcorp_spread if year(date)>2009 & year(date)<2015 & (term==91 | term==182)
sum refcorp_spread if year(date)>2009 & year(date)<2015 & (term==91 | term==182) & (window_big_2011==1 | window_big_2013==1)

sum refcorp_spread if year(date)>2010 & year(date)<2014 & (term==3650 | term==1825)
sum refcorp_spread if year(date)>2010 & year(date)<2014 & (term==3650 | term==1825) & (window_2011==1 | window_2013==1)
sum refcorp_spread if year(date)>2009 & year(date)<2015 & (term==3650 | term==1825)
sum refcorp_spread if year(date)>2009 & year(date)<2015 & (term==3650 | term==1825) & (window_big_2011==1 | window_big_2013==1)
log close

* Coupons
use "Data/Created_files/coupons_basic_regressions_CRSP_1990_2020.dta", clear
drop if time_to_mat<5
drop if yld_early<-60
gen yld_early_ois = yld_early - ois_imputed
drop if missing(ois_imputed)

gen window_big_2011=0
replace window_big_2011=1 if date>mdy(5,15,2011) & date<mdy(10,20,2011)
gen window_big_2013=0
replace window_big_2013=1 if date>mdy(5,19,2013) & date<mdy(3,17,2014)


log using "Output/summary_stats.log", append
foreach var of varlist yld_early ois_imputed yld_early_ois normalized_bid_ask_spread {
	display "2011 to 2013"
	sum `var' if year(date)>2010 & year(date)<2014
	display "In Window 2011 and 2013"
	sum `var' if window_2011==1 | window_2013==1
	display "2010 to 2014"
	sum `var' if year(date)>2009 & year(date)<2015
	display "In Big Window 2011 and 2013"
	sum `var' if window_big_2011==1 | window_big_2013==1
}
log close

* Matched bills

use "Data/Created_files/bills_coupon_match.dta", clear
gen window_big_2011=0
replace window_big_2011=1 if date>mdy(5,15,2011) & date<mdy(10,20,2011)
gen window_big_2013=0
replace window_big_2013=1 if date>mdy(5,19,2013) & date<mdy(3,17,2014)
log using "Output/summary_stats.log", append
foreach var of varlist yld_diff {
	display "2011 to 2013"
	sum `var' if year(date)>2010 & year(date)<2014
	display "In Window 2011 and 2013"
	sum `var' if window_2011==1 | window_2013==1
	display "2010 to 2014"
	sum `var' if year(date)>2009 & year(date)<2015
	display "In Big Window 2011 and 2013"
	sum `var' if window_big_2011==1 | window_big_2013==1
}
log close

* Control Variables

use Data/Created_files/control_variables_long.dta, clear
gen window_big_2011=0
replace window_big_2011=1 if date>mdy(5,15,2011) & date<mdy(10,20,2011)
gen window_big_2013=0
replace window_big_2013=1 if date>mdy(5,19,2013) & date<mdy(3,17,2014)
log using "Output/summary_stats.log", append
foreach var of varlist cds_us cds6m_us avg_ba_sp_y avg_norm_ba_sp tedrate refcorp_spread onrun_svenyspread basis_2y1 {
	display "2011 to 2013"
	sum `var' if year(date)>2010 & year(date)<2014
	display "In Window 2011 and 2013"
	sum `var' if window_2011==1 | window_2013==1
	display "2010 to 2014"
	sum `var' if year(date)>2009 & year(date)<2015
	display "In Big Window 2011 and 2013"
	sum `var' if window_big_2011==1 | window_big_2013==1
}
log close


 use "Data/Created_files/control_variables_long_coupons.dta", clear
 
 gen window_big_2011=0
replace window_big_2011=1 if date>mdy(5,15,2011) & date<mdy(10,20,2011)
gen window_big_2013=0
replace window_big_2013=1 if date>mdy(5,19,2013) & date<mdy(3,17,2014)
log using "Output/summary_stats.log", append
foreach var of varlist avg_norm_ba_sp {
	display "2011 to 2013"
	sum `var' if year(date)>2010 & year(date)<2014
	display "In Window 2011 and 2013"
	sum `var' if window_2011==1 | window_2013==1
	display "2010 to 2014"
	sum `var' if year(date)>2009 & year(date)<2015
	display "In Big Window 2011 and 2013"
	sum `var' if window_big_2011==1 | window_big_2013==1
}
log close

use Data/Created_files/cds_data_qual.dta, clear 
 

 gen window_big_2011=0
replace window_big_2011=1 if date>mdy(5,15,2011) & date<mdy(10,20,2011)
gen window_big_2013=0
replace window_big_2013=1 if date>mdy(5,19,2013) & date<mdy(3,17,2014)
log using "Output/summary_stats.log", append
foreach var of varlist data_qual6m {
	display "2011 to 2013"
	sum `var' if year(date)>2010 & year(date)<2014

	display "2010 to 2014"
	sum `var' if year(date)>2009 & year(date)<2015
	display "In Big Window 2011 and 2013"
	sum `var' if window_big_2011==1 | window_big_2013==1
}
log close





***************** Table 2 ********************************************************************************************
 * Bills Part of Table (Columns 1 to 4)
 
 use "Data/Created_files/bill_basic_regressions_CRSP_1990_2020.dta", clear
drop if year(date)<2010
drop if year(date)>2014

gen fd_yld_early_ois = fd_yld_early - fd_ois_imputed
gen fd_yld_early_ff = fd_yld_early - 100*fd_avg_effr
gen fd_avg_effr_100 = 100*fd_avg_effr 


gen yld_early_ois = yld_early - ois_imputed

egen panelvar = group(payable_early)
egen obs=group(date)
xtset panelvar obs




eststo clear
eststo: ivreghdfe fd_yld_early_ois fd_d_2011_* fd_d_2013_* fd_p_2011_*  fd_p_2013_* if time_to_mat_early > 5 & year(date)>2010 & year(date)<2014 ,a(panelvar) robust bw(5)

esttab using "Output/table2_bills.csv", replace star(* 0.10 ** 0.05 *** 0.01) b(3) se(3) scalar(N r2 N_clust1 )


 * Coupons Part of Table (Columns 5 and 6)
 
 
use "Data/Created_files/coupons_basic_regressions_CRSP_1990_2020.dta", clear
drop _merge


drop date_bus 
egen date_bus = group(date)

xtset kytreasno date_bus
foreach var of varlist yld_early ois_imputed d_* p_*  i_*  {
	gen fd_`var'=d.`var'
}




gen time_dow=time_to_mat
replace time_dow=182 if time_to_mat>182
gen dow=dow(date)
gen fd_yld_early_ois = fd_yld_early - fd_ois_imputed


drop fd_d_2013_2* fd_d_2013_3* fd_p_2013_2* fd_p_2013_3* fd_i_2013_2* fd_i_2013_3* fd_*_1996* fd_*_2002* fd_*_2003* fd_*_2004* fd_*_2006* fd_*_2014* fd_*_2015* fd_*_2017* fd_*_2018* fd_*_2019* 

eststo clear

eststo: ivreghdfe fd_yld_early_ois fd_d_* fd_p_* fd_i_* i.dow##i.time_dow  if time_to_mat > 5 &  year(date)>2010 & year(date)<2014 ,a(kytreasno) robust bw(5)
esttab using "Output/table2_coupons.csv",  replace b(6) se(6) scalar(N r2 N_clust1 N_clust2)
 
***************** Table 3 ********************************************************************************************
* First Refcorp Spreads, Columns 1, 2,4 , and 5
use "Data/Created_files/refcorp_spread_data.dta", replace 


eststo clear
eststo: ivreghdfe fd_refcorp_spread fd_d_2011_* fd_d_2013_* if  year(date)>2010 & year(date)<2014 & (term==91 | term==182) , a(term) robust bw(5)
eststo: ivreghdfe fd_refcorp_spread fd_d_2011_* fd_d_2013_* if  year(date)>2010 & year(date)<2014 & (term==3650 | term==1825) , a(term) robust bw(5)

esttab using "Output/table3_refcorp.csv",  replace b(6) se(6) scalar(N r2 N_clust1 N_clust2)

* Matched Coupon minus Bill, Columns 3 and 6

use  "Data/Created_files/bills_coupon_match.dta", replace


drop fd_d_2013_2_* fd_d_2013_3_*  fd_p_2013_2_* fd_p_2013_3_*
eststo clear
eststo: ivreghdfe fd_yld_diff fd_d_2011_* fd_d_2013_* fd_p_2011_* fd_p_2013_* i.dow##i.time_dow if time_to_mat>5 & year(date)>2010 & year(date)<2014 , a(kytreasno) robust bw(5)

esttab using "Output/table3_bills_coupon_match.csv",  replace b(6) se(6) scalar(N r2 N_clust1 N_clust2)


***************** Table 4 ********************************************************************************************
use "Data/Created_files/triple_diff_data.dta", clear

eststo clear
eststo: ivreghdfe fd_yld_early_ois fd_d_*_b   fd_p_*_b if type==1, a(panelvar) robust bw(5) partial( fd_p_*_b )
eststo: ivreghdfe fd_yld_early_ois fd_d_*_dn fd_d_*_b   fd_p_*_dn fd_p_*_b if type!=2, a(panelvar) robust bw(5) partial( fd_p_*_dn fd_p_*_b )
esttab using "Output/table4.csv",  replace b(6) se(6) scalar(N r2 N_clust1 N_clust2)





***************** Table 5 ********************************************************************************************
* First, Bills (Columns 1 - 3)



use "Data/Created_files/bill_basic_regressions_CRSP_1990_2020.dta", clear
drop _merge

* Grab control variables that vary across, but not within, dates
joinby date using "Data/Created_files/control_variables_long.dta", unmatched(master)



egen obs=group(date)
xtset payable_early obs


* T-bill/OIS spread
gen tbill_ois_spread = yld_early - ois_imputed

bysort payable_early: gen fd_tbill_ois_spread = tbill_ois_spread - tbill_ois_spread[_n-1]


* Interaction of Bid-Ask and cds 
gen ba_cds_6_inter = cds6m_us*avg_norm_ba_sp
bysort payable_early: gen fd_ba_cds_6_inter=ba_cds_6_inter - ba_cds_6_inter[_n-1]


gen cds_6_sq = cds6m_us*cds6m_us
bysort payable_early: gen fd_cds_6_sq=cds_6_sq - cds_6_sq[_n-1]


gen bid_ask_sq = avg_norm_ba_sp*avg_norm_ba_sp
bysort payable_early: gen fd_bid_ask_sq=bid_ask_sq - bid_ask_sq[_n-1]



gen window_big_2011=0
replace window_big_2011=1 if date>mdy(5,15,2011) & date<mdy(10,20,2011)
gen window_big_2013=0
replace window_big_2013=1 if date>mdy(5,19,2013) & date<mdy(3,17,2014)



foreach var in avg_norm_ba_sp cds6m_us cds_6_sq bid_ask_sq ba_cds_6_inter{
	foreach i in 2011 2013 {
		gen fd_win_big_`i'_`var'=window_big_`i'*fd_`var'
	}
}

eststo clear

eststo: ivreghdfe fd_tbill_ois_spread   fd_cds6m_us fd_win_big_2011_cds6m_us fd_win_big_2013_cds6m_us  fd_avg_norm_ba_sp   fd_win_big_2011_avg_norm_ba_sp fd_win_big_2013_avg_norm_ba_sp  if time_to_mat_early > 5  & year(date)>2009 & year(date)<2015 ,a(payable_early) robust bw(5)

eststo: ivreghdfe fd_tbill_ois_spread   fd_cds6m_us fd_win_big_2011_cds6m_us fd_win_big_2013_cds6m_us  fd_avg_norm_ba_sp   fd_win_big_2011_avg_norm_ba_sp fd_win_big_2013_avg_norm_ba_sp  fd_cds_6_sq fd_win_big_2011_cds_6_sq fd_win_big_2013_cds_6_sq fd_bid_ask_sq fd_win_big_2011_bid_ask_sq fd_win_big_2013_bid_ask_sq  if time_to_mat_early > 5  & year(date)>2009 & year(date)<2015 ,a(payable_early) robust bw(5)

eststo: ivreghdfe fd_tbill_ois_spread   fd_cds6m_us fd_win_big_2011_cds6m_us fd_win_big_2013_cds6m_us  fd_avg_norm_ba_sp   fd_win_big_2011_avg_norm_ba_sp fd_win_big_2013_avg_norm_ba_sp   fd_ba_cds_6_inter  fd_win_big_2011_ba_cds_6_inter fd_win_big_2013_ba_cds_6_inter   if time_to_mat_early > 5  & year(date)>2009 & year(date)<2015 ,a(payable_early) robust bw(5)

esttab using "Output/table5_bills.csv",  replace b(3) se(3) scalar(N r2 N_clust1 N_clust2)


* Next, Coupons (Columns 4 - 6)


use "Data/Created_files/coupons_basic_regressions_CRSP_1990_2020.dta", clear
drop _merge
joinby date using "Data/Created_files/control_variables_long_coupons.dta", unmatched(master)





gen cds_5_sq=cds_us*cds_us 
gen bid_ask_sq = normalized_bid_ask_spread * normalized_bid_ask_spread
gen cds_ba_inter = cds_us * normalized_bid_ask_spread
drop date_bus
egen date_bus = group(date)
xtset kytreasno date_bus
foreach var of varlist yld_early ois_imputed normalized_bid_ask_spread cds_5_sq bid_ask_sq cds_ba_inter {
	gen fd_`var'=d.`var'
}






gen window_big_2011=0
replace window_big_2011=1 if date>mdy(5,15,2011) & date<mdy(10,20,2011)
gen window_big_2013=0
replace window_big_2013=1 if date>mdy(5,19,2013) & date<mdy(3,17,2014)


foreach var in avg_norm_ba_sp cds_us cds_5_sq bid_ask_sq cds_ba_inter  {
	foreach i in 2011 2013 {
		gen fd_win_big_`i'_`var'=window_big_`i'*fd_`var'
	}
}


gen time_dow=time_to_mat
replace time_dow=182 if time_to_mat>182
gen dow=dow(date)
gen fd_yld_early_ois = fd_yld_early - fd_ois_imputed

eststo clear 
eststo: ivreghdfe fd_yld_early_ois fd_cds_us fd_win_big_2011_cds_us fd_win_big_2013_cds_us  fd_avg_norm_ba_sp   fd_win_big_2011_avg_norm_ba_sp fd_win_big_2013_avg_norm_ba_sp i.dow##i.time_dow  if time_to_mat > 5  & year(date)>2009 & year(date)<2015 ,a(kytreasno) robust bw(5)
eststo: ivreghdfe fd_yld_early_ois fd_cds_us fd_win_big_2011_cds_us fd_win_big_2013_cds_us  fd_avg_norm_ba_sp   fd_win_big_2011_avg_norm_ba_sp fd_win_big_2013_avg_norm_ba_sp   fd_cds_5_sq fd_win_big_2011_cds_5_sq fd_win_big_2013_cds_5_sq fd_bid_ask_sq fd_win_big_2011_bid_ask_sq fd_win_big_2013_bid_ask_sq i.dow##i.time_dow   if time_to_mat > 5  & year(date)>2009 & year(date)<2015 ,a(kytreasno) robust bw(5)
eststo: ivreghdfe fd_yld_early_ois fd_cds_us fd_win_big_2011_cds_us fd_win_big_2013_cds_us  fd_avg_norm_ba_sp   fd_win_big_2011_avg_norm_ba_sp fd_win_big_2013_avg_norm_ba_sp   fd_cds_ba_inter  fd_win_big_2011_cds_ba_inter fd_win_big_2013_cds_ba_inter  i.dow##i.time_dow    if time_to_mat > 5  & year(date)>2009 & year(date)<2015 ,a(kytreasno) robust bw(5)


esttab using "Output/table5_coupons.csv",  replace b(3) se(3) scalar(N r2 N_clust1 N_clust2)

***************** Table 6 ********************************************************************************************




use "Data/Created_files/bill_basic_regressions_CRSP_1990_2020.dta", clear
drop _merge

joinby date using Data/Created_files/control_variables_long.dta, unmatched(master)

drop normalized_bid_ask_spread





egen obs=group(date)
xtset payable_early obs



* T-bill/OIS spread
gen tbill_ois_spread = yld_early - ois_imputed

bysort payable_early: gen fd_tbill_ois_spread = tbill_ois_spread - tbill_ois_spread[_n-1]



* Interaction of Bid-Ask and cds 
gen ba_cds_6_inter = cds6m_us*avg_norm_ba_sp
bysort payable_early: gen fd_ba_cds_6_inter=ba_cds_6_inter - ba_cds_6_inter[_n-1]


gen cds_6_sq = cds6m_us*cds6m_us
bysort payable_early: gen fd_cds_6_sq=cds_6_sq - cds_6_sq[_n-1]


gen bid_ask_sq = avg_norm_ba_sp*avg_norm_ba_sp
bysort payable_early: gen fd_bid_ask_sq=bid_ask_sq - bid_ask_sq[_n-1]



gen window_big_2011=0
replace window_big_2011=1 if date>mdy(5,15,2011) & date<mdy(10,20,2011)
gen window_big_2013=0
replace window_big_2013=1 if date>mdy(5,19,2013) & date<mdy(3,17,2014)

foreach var in avg_norm_ba_sp cds6m_us cds_6_sq bid_ask_sq ba_cds_6_inter {
	foreach i in 2011 2013 {
		gen fd_win_big_`i'_`var'=window_big_`i'*fd_`var'
	}
}


***********************************************************************************************
***********************************************************************************************

/*
** Do market perceptions of Treasury safety affect liquidity in a manner consistent with information sensitivity of debt?
** Original version of these regressions in cds_std.do
*/
drop _merge
joinby date using "Data/Created_files/cds_data_qual.dta", unmatched(master)

eststo clear
eststo: ivreghdfe fd_normalized_bid_ask_spread fd_cds6m_us i.at_risk##(c.fd_win_big_2011_cds6m_us c.fd_win_big_2013_cds6m_us) if time_to_mat_early > 5 & year(date)>2009 & year(date)<2015 & !missing(fd_ois_imputed),a(payable_early) robust bw(5)
eststo: ivreghdfe fd_normalized_bid_ask_spread fd_cds6m_us i.at_risk##(c.fd_win_big_2011_cds6m_us c.fd_win_big_2013_cds6m_us) fd_cds_6_sq i.at_risk##(c.fd_win_big_2011_cds_6_sq c.fd_win_big_2013_cds_6_sq) if time_to_mat_early > 5 & year(date)>2009 & year(date)<2015 & !missing(fd_ois_imputed),a(payable_early) robust bw(5)

drop if missing(fd_avg_norm_ba_sp)
bysort date: gen obs1=_n
keep if obs1==1
xtset obs1 obs

eststo: ivreghdfe fd_data6m_5d fd_avg_norm_ba_sp fd_win_big_2011_avg_norm_ba_sp fd_win_big_2013_avg_norm_ba_sp if year(date)>2009 & year(date)<2015 , robust bw(5)


esttab using "Output/table6.csv",  replace b(3) se(3) scalar(N r2 N_clust1 N_clust2)

**********************************************************************************************************************
**********************************************************************************************************************
**********************************************************************************************************************
* Online Appendix Tables 



***************** Table A.2 ******************************************************************************************

use "Data/Created_files/bill_basic_regressions_CRSP_1990_2020.dta", clear
drop if year(date)<2010
drop if year(date)>2014

gen fd_yld_early_ois = fd_yld_early - fd_ois_imputed
gen fd_yld_early_ff = fd_yld_early - 100*fd_avg_effr
gen fd_avg_effr_100 = 100*fd_avg_effr 


gen yld_early_ois = yld_early - ois_imputed

egen panelvar = group(payable_early)
egen obs=group(date)
xtset panelvar obs




eststo clear
eststo: ivreghdfe fd_yld_early_ff fd_d_2011_* fd_d_2013_* fd_p_2011_*  fd_p_2013_* if time_to_mat_early > 5 & year(date)>2010 & year(date)<2014 ,a(panelvar) robust bw(5)

esttab using "Output/tablea2.csv", replace star(* 0.10 ** 0.05 *** 0.01) b(3) se(3) scalar(N r2 N_clust1 )




***************** Table A.3 ******************************************************************************************
drop _merge
joinby date using "Data/Created_files/constant_maturity.dta", unmatched(master)
gen ten_min_three_mo = 100*(riflgfcy10_nb - riflgfcm03_nb)
bysort payable_early (date): gen fd_ten_min_three_mo = ten_min_three_mo - ten_min_three_mo[_n - 1]

eststo clear
eststo: ivreghdfe fd_yld_early_ois fd_d_2011_* fd_d_2013_* fd_p_2011_*  fd_p_2013_* fd_ten_min_three_mo if time_to_mat_early > 5 & year(date)>2010 & year(date)<2014 ,a(panelvar) robust bw(5)

esttab using "Output/tablea3.csv", replace star(* 0.10 ** 0.05 *** 0.01) b(3) se(3) scalar(N r2 N_clust1 )



***************** Table A.4 ******************************************************************************************

use "Data/Created_files/bill_basic_regressions_CRSP_1990_2020.dta", clear

gen fd_yld_early_ois = fd_yld_early - fd_ois_imputed
gen fd_yld_early_ff = fd_yld_early - 100*fd_avg_effr



gen yld_early_ois = yld_early - ois_imputed

egen panelvar = group(payable_early)
egen obs=group(date)
xtset panelvar obs


*Key Dates

* Estimate regressions separately for each episode
* Key Dates
* 1996 Episode
local key_1996 = mdy(3,29,1996)
local maxatrisk_1996 = mdy(4,29,1996)
local start_1996 = mdy(11,15,1995)
* 2002 Episode
local key_2002 = mdy(6,28,2002)
local maxatrisk_2002 = mdy(7,28,2002)
local start_2002 = mdy(5,16,2002)
* 2003 Episode
local key_2003 = mdy(5,27,2003)
local maxatrisk_2003 = mdy(6,27,2003)
local start_2003 = mdy(2,20,2003)
* 2004 Episode
local key_2004 = mdy(11,15,2004)
local maxatrisk_2004 = mdy(12,15,2004)
local start_2004 = mdy(11,15,2004)
* 2006 Episode
local key_2006 = mdy(3,20,2006)
local maxatrisk_2006 = mdy(4,20,2006)
local start_2006 = mdy(2,19,2006)
* 2012 Episode
local key_2012 = mdy(3,1,2013)
local maxatrisk_2012 = mdy(4,1,2013)
local start_2012 = mdy(12,31,2012)
* 2014 Episode
local key_2014 = mdy(2,27,2014)
local maxatrisk_2014 = mdy(3,27,2014)
local start_2014 = mdy(2,10,2014)
* 2015 Episode
local key_2015 = mdy(11,5,2015)
local maxatrisk_2015 = mdy(12,5,2015)
local start_2015 = mdy(3,16,2015)
* 2017 Episode
local key_2017 = mdy(9,29,2017)
local maxatrisk_2017 = mdy(10,29,2017)
local start_2017 = mdy(3,17,2017)
* 2018 Episode
local key_2018 = mdy(2,28,2018)
local maxatrisk_2018 = mdy(3,28,2018)
local start_2018 = mdy(12,8,2017)
* 2019 Episode
local key_2019 = mdy(9,1,2019)
local maxatrisk_2019 = mdy(10,1,2019)
local start_2019 = mdy(3,4,2019)

foreach ep in 1996 2002 2003 2004 2006 2012 2014 2015 2017 2018 2019 {
	local min_`ep' = `key_`ep'' - 21
	local max_`ep' = `key_`ep'' + 21
}

* 2011 Episode
local key_2011 = mdy(8,2,2011)
* 2013 Episode
local key_2013 = mdy(10,17,2013)


* Create At-risk securities and date dummies during episodes
foreach ep in  1996 2002 2003 2004 2006 2012 2014 2015 2017 2018 2019 {
	gen at_risk_`ep'=0
	replace at_risk_`ep'=1 if payable_early > `start_`ep'' & payable_early<`maxatrisk_`ep''
	local first=`min_`ep''
	local last=`max_`ep''
forvalues i=`first'/`last' {
	local month=month(`i')
	local day=day(`i')
	local year=year(`i')
	gen d_`year'_`month'_`day'=0 
	replace d_`year'_`month'_`day'=1 if date==`i'
	su d_`year'_`month'_`day', meanonly
	replace d_`year'_`month'_`day'=. if `r(min)'==`r(max)'
	missings dropvars d_`year'_`month'_`day', force
}
}
rename at_risk at_risk_orig
egen at_risk=rowmax(at_risk_*)

* Create date - payable dummies for at-risk securities
foreach ep in 1996 2002 2003 2004 2006 2012 2014 2015 2017 2018 2019  {
	local first=`min_`ep''
	local last=`max_`ep''
	local p_start = `key_`ep'' - 15
	local p_end = `key_`ep'' + 45
	forvalues i=`first'/`last' {
		local date_month=month(`i')
		local date_day=day(`i')
		local date_year=year(`i')
		forvalues j=`p_start'/`p_end' {
			local pay_month=month(`j')
			local pay_day=day(`j')
			local pay_year=year(`j')
			gen p_`pay_year'_`pay_month'_`pay_day'_d_`date_year'_`date_month'_`date_day'=0
			replace p_`pay_year'_`pay_month'_`pay_day'_d_`date_year'_`date_month'_`date_day'=1 if date==`i' & payable_early==`j' & at_risk_`ep'==1
			su p_`pay_year'_`pay_month'_`pay_day'_d_`date_year'_`date_month'_`date_day', meanonly
			replace p_`pay_year'_`pay_month'_`pay_day'_d_`date_year'_`date_month'_`date_day'=. if `r(min)'==`r(max)'
			missings dropvars p_`pay_year'_`pay_month'_`pay_day'_d_`date_year'_`date_month'_`date_day', force

		}
	}
}

drop fd_d_* fd_p_* 
foreach var of varlist d_* p_* {
	bysort payable_early (date): gen fd_`var' = `var' - `var'[_n-1]
}

* OIS control
foreach ep in 2002 2003 2004 2006 2011 2013 2014 2015 2017 2018 2019{
*foreach ep in 2002 2003 2004 2006 2011 {
	eststo clear
	eststo: ivreghdfe fd_yld_early_ois fd_d* fd_p* if time_to_mat_early > 5 & date>`key_`ep'' - 182 & date<`key_`ep'' + 182, a(payable_early) robust bw(5)
esttab using "Output/tablea4_`ep'.csv", replace star(* 0.10 ** 0.05 *** 0.01) b(3) se(3) scalar(N r2 N_clust1 )
}



* Fed funds control


foreach ep in 1996 2019{
	eststo clear
	eststo: ivreghdfe fd_yld_early_ff fd_d_* fd_p_* if time_to_mat_early > 5 & date>`key_`ep'' - 182 & date<`key_`ep'' + 182, a(payable_early) robust bw(5)
esttab using "Output/tablea4_`ep'_ff.csv", replace star(* 0.10 ** 0.05 *** 0.01) b(3) se(3) scalar(N r2 N_clust1 )
}







***************** Table A.6 ******************************************************************************************



use "Data/Created_files/bills_coupon_match.dta", clear



eststo clear

* CDS
eststo: ivreghdfe fd_yld_early_ois fd_cds6m_us fd_win_2011_cds6m_us fd_win_2013_cds6m_us i.dow##i.time_dow if time_to_mat>5 & year(date)>2010 & year(date)<2014 , a(kytreasno) robust bw(5)
eststo: ivreghdfe fd_yld_early_bill_ois fd_cds6m_us fd_win_2011_cds6m_us fd_win_2013_cds6m_us i.dow##i.time_dow if time_to_mat>5 & year(date)>2010 & year(date)<2014 , a(kytreasno) robust bw(5)
eststo: ivreghdfe fd_yld_diff_ois fd_cds6m_us fd_win_2011_cds6m_us fd_win_2013_cds6m_us i.dow##i.time_dow if time_to_mat>5 & year(date)>2010 & year(date)<2014 , a(kytreasno) robust bw(5)

*Bid-Ask
eststo: ivreghdfe fd_yld_early_ois fd_avg_norm_ba_sp fd_win_2011_avg_norm_ba_sp fd_win_2013_avg_norm_ba_sp  i.dow##i.time_dow if time_to_mat>5 & year(date)>2010 & year(date)<2014 , a(kytreasno) robust bw(5)
eststo: ivreghdfe fd_yld_early_bill_ois fd_avg_norm_ba_sp fd_win_2011_avg_norm_ba_sp  fd_win_2013_avg_norm_ba_sp  i.dow##i.time_dow if time_to_mat>5 & year(date)>2010 & year(date)<2014 , a(kytreasno) robust bw(5)
eststo: ivreghdfe fd_yld_diff_ois fd_avg_norm_ba_sp fd_win_2011_avg_norm_ba_sp  fd_win_2013_avg_norm_ba_sp  i.dow##i.time_dow if time_to_mat>5 & year(date)>2010 & year(date)<2014 , a(kytreasno) robust bw(5)



* Combined
eststo: ivreghdfe fd_yld_early_ois fd_cds6m_us fd_win_2011_cds6m_us fd_win_2013_cds6m_us fd_avg_norm_ba_sp fd_win_2011_avg_norm_ba_sp fd_win_2013_avg_norm_ba_sp  i.dow##i.time_dow if time_to_mat>5 & year(date)>2010 & year(date)<2014 , a(kytreasno) robust bw(5)
eststo: ivreghdfe fd_yld_early_bill_ois fd_cds6m_us fd_win_2011_cds6m_us fd_win_2013_cds6m_us fd_avg_norm_ba_sp fd_win_2011_avg_norm_ba_sp fd_win_2013_avg_norm_ba_sp  i.dow##i.time_dow if time_to_mat>5 & year(date)>2010 & year(date)<2014 , a(kytreasno) robust bw(5)
eststo: ivreghdfe fd_yld_diff_ois fd_cds6m_us fd_win_2011_cds6m_us fd_win_2013_cds6m_us  fd_avg_norm_ba_sp fd_win_2011_avg_norm_ba_sp fd_win_2013_avg_norm_ba_sp  i.dow##i.time_dow if time_to_mat>5 & year(date)>2010 & year(date)<2014 , a(kytreasno) robust bw(5)



esttab using "Output/tablea6.csv", replace b(3) se(3) scalar(N r2 N_clust1 N_clust2)




***************** Table B.1 ******************************************************************************************

use "Data/Created_files/bill_basic_regressions_CRSP_1990_2020.dta", clear
drop _merge
joinby payable_early date using "Data/Created_files/fannie_yields_2010_2014.dta", unmatched(both)
drop _merge

/*
** Spread and first-differenced spread between maturity-matched T-bills and agency DNs (Difference should be liquidity-related)
*/
gen fannie_spread =  yield_fannie - yld_early 


bysort payable_early (date): gen fd_fannie_spread = fannie_spread - fannie_spread[_n - 1]


* Grab control variables that vary across, but not within, dates
joinby date using Data/Created_files/control_variables_long.dta, unmatched(master)

drop normalized_bid_ask_spread


egen obs=group(date)
xtset payable_early obs


* T-bill/OIS spread
gen tbill_ois_spread = yld_early - ois_imputed

bysort payable_early: gen fd_tbill_ois_spread = tbill_ois_spread - tbill_ois_spread[_n-1]

gen fd_tedsp=100*fd_tedrate




gen window_big_2011=0
replace window_big_2011=1 if date>mdy(5,15,2011) & date<mdy(10,20,2011)
gen window_big_2013=0
replace window_big_2013=1 if date>mdy(5,19,2013) & date<mdy(3,17,2014)
rename fd_onrun_svenyspread fd_onrun_sveny
rename fd_win_2011_onrun_svenyspread fd_win_2011_onrun_sveny
rename fd_win_2013_onrun_svenyspread fd_win_2013_onrun_sveny


foreach var in avg_norm_ba_sp cds6m_us cds_us tedsp fannie_spread basis_2y1 onrun_sveny {
	foreach i in 2011 2013 {
		gen fd_win_big_`i'_`var'=window_big_`i'*fd_`var'
	}
}

eststo clear
eststo: ivreghdfe fd_tbill_ois_spread  fd_cds6m_us fd_win_big_2011_cds6m_us fd_win_big_2013_cds6m_us  fd_avg_norm_ba_sp   fd_win_big_2011_avg_norm_ba_sp fd_win_big_2013_avg_norm_ba_sp     if time_to_mat_early > 5  & year(date)>2009 & year(date)<2015 ,a(payable_early) robust bw(5)

eststo: ivreghdfe fd_tbill_ois_spread  fd_cds_us fd_win_big_2011_cds_us fd_win_big_2013_cds_us  fd_avg_norm_ba_sp   fd_win_big_2011_avg_norm_ba_sp fd_win_big_2013_avg_norm_ba_sp   if time_to_mat_early > 5  & year(date)>2009 & year(date)<2015 ,a(payable_early) robust bw(5)
eststo: ivreghdfe fd_tbill_ois_spread  fd_tedsp fd_win_big_2011_tedsp fd_win_big_2013_tedsp  fd_avg_norm_ba_sp   fd_win_big_2011_avg_norm_ba_sp fd_win_big_2013_avg_norm_ba_sp   if time_to_mat_early > 5  & year(date)>2009 & year(date)<2015 ,a(payable_early) robust bw(5)

eststo: ivreghdfe fd_tbill_ois_spread   fd_fannie_spread   fd_win_big_2011_fannie_spread fd_win_big_2013_fannie_spread  fd_cds6m_us fd_win_big_2011_cds6m_us fd_win_big_2013_cds6m_us    if time_to_mat_early > 5  & year(date)>2009 & year(date)<2015 ,a(payable_early) robust bw(5)
eststo: ivreghdfe fd_tbill_ois_spread   fd_onrun_sveny   fd_win_big_2011_onrun_sveny fd_win_big_2013_onrun_sveny fd_reopening fd_cds6m_us fd_win_big_2011_cds6m_us fd_win_big_2013_cds6m_us   if time_to_mat_early > 5  & year(date)>2009 & year(date)<2015 ,a(payable_early) robust bw(5)
eststo: ivreghdfe fd_tbill_ois_spread   fd_basis_2y1   fd_win_big_2011_basis_2y1 fd_win_big_2013_basis_2y1 new_contract  fd_cds6m_us fd_win_big_2011_cds6m_us fd_win_big_2013_cds6m_us    if time_to_mat_early > 5  & year(date)>2009 & year(date)<2015 ,a(payable_early) robust bw(5)
esttab using "Output/tableb1.csv", replace star(* 0.10 ** 0.05 *** 0.01) b(3) se(3) scalar(N r2 N_clust1 )
